uikit library

Classes

CATransform3D
CGAffineTransform
CGColor
CGContext
CGImage
NSDirectionalEdgeInsets
NSDirectionalRectEdge
NSLayoutFormatOptions
NSLineBreakStrategy
ObjCBlock_ffiVoid
Construction methods for objc.ObjCBlock<ffi.Void Function()>.
ObjCBlock_ffiVoid_bool
Construction methods for objc.ObjCBlock<ffi.Void Function(ffi.Bool)>.
ObjCBlock_ffiVoid_NSData_NSError
Construction methods for objc.ObjCBlock<ffi.Void Function(objc.NSData?, objc.NSError?)>.
ObjCBlock_ffiVoid_NSError
Construction methods for objc.ObjCBlock<ffi.Void Function(objc.NSError)>.
ObjCBlock_ffiVoid_NSError$1
Construction methods for objc.ObjCBlock<ffi.Void Function(objc.NSError?)>.
ObjCBlock_ffiVoid_UIAction
Construction methods for objc.ObjCBlock<ffi.Void Function(UIAction)>.
ObjCBlock_ffiVoid_UIAction_objcObjCObjectImpl_objcObjCSelector_UIControlEvents_bool
Construction methods for objc.ObjCBlock<ffi.Void Function(UIAction?, ffi.Pointer<objc.ObjCObjectImpl>?, ffi.Pointer<objc.ObjCSelector>, ffi.UnsignedLong, ffi.Pointer<ffi.Bool>)>.
ObjCBlock_ffiVoid_UIAlertAction
Construction methods for objc.ObjCBlock<ffi.Void Function(UIAlertAction)>.
ObjCBlock_ffiVoid_UIButton
Construction methods for objc.ObjCBlock<ffi.Void Function(UIButton)>.
ObjCBlock_ffiVoid_UITextField
Construction methods for objc.ObjCBlock<ffi.Void Function(UITextField)>.
ObjCBlock_NSDictionary_NSDictionary
Construction methods for objc.ObjCBlock<objc.NSDictionary Function(objc.NSDictionary)>.
ObjCBlock_UIColor_UITraitCollection
Construction methods for objc.ObjCBlock<UIColor Function(UITraitCollection)>.
ObjCBlock_UIPointerStyle_UIButton_UIPointerEffect_UIPointerShape
Construction methods for objc.ObjCBlock<UIPointerStyle? Function(UIButton, UIPointerEffect, UIPointerShape)>.
SfSymbols
UIControlEvents
UIControlState
UIEdgeInsets
UIInterfaceOrientationMask
UIMenuElementAttributes
UIMenuOptions
UIOffset
UIRectEdge
UIRemoteNotificationType
UIViewAnimationOptions
UIViewAutoresizing
UIViewKeyframeAnimationOptions

Enums

CGBlendMode
NSLayoutAttribute
NSLayoutRelation
NSLineBreakMode
NSTextAlignment
NSWritingDirection
UIActivityIndicatorViewStyle
UIAlertActionStyle
UIAlertControllerStyle
UIApplicationState
UIBackgroundRefreshStatus
UIBarButtonItemStyle
UIBarButtonSystemItem
UIBarMetrics
UIBarStyle
UIBaselineAdjustment
UIButtonRole
UIButtonType
UIControlContentHorizontalAlignment
UIControlContentVerticalAlignment
UIDynamicItemCollisionBoundsType
UIEditingInteractionConfiguration
UIEventSubtype
UIImageOrientation
UIImageRenderingMode
UIImageResizingMode
UIInterfaceOrientation
UIKeyboardAppearance
UIKeyboardType
UILayoutConstraintAxis
UIMenuElementState
UIModalPresentationStyle
UIModalTransitionStyle
UINavigationItemBackButtonDisplayMode
UINavigationItemLargeTitleDisplayMode
UIPageControlBackgroundStyle
UIPageControlInteractionState
UIProgressViewStyle
UIReturnKeyType
UISceneActivationState
UIScrollViewContentInsetAdjustmentBehavior
UIScrollViewIndexDisplayMode
UIScrollViewIndicatorStyle
UIScrollViewKeyboardDismissMode
UISemanticContentAttribute
UIStackViewAlignment
UIStackViewDistribution
UIStatusBarAnimation
UIStatusBarStyle
UISwitchStyle
UISystemAnimation
UITabBarItemPositioning
UITabBarSystemItem
UITextAlternativeStyle
UITextAutocapitalizationType
UITextAutocorrectionType
UITextBorderStyle
UITextFieldViewMode
UITextLayoutDirection
UITextSmartDashesType
UITextSmartInsertDeleteType
UITextSmartQuotesType
UITextSpellCheckingType
UITextStorageDirection
UITitlebarSeparatorStyle
UITitlebarTitleVisibility
UITitlebarToolbarStyle
UIUserInterfaceIdiom
UIUserInterfaceLayoutDirection
UIUserInterfaceStyle
UIViewAnimationCurve
UIViewAnimationTransition
UIViewContentMode
UIViewTintAdjustmentMode

Extension Types

CAAction
WARNING: CAAction is a stub. To generate bindings for this class, include CAAction in your config's objc-protocols list.
CALayer
WARNING: CALayer is a stub. To generate bindings for this class, include CALayer in your config's objc-interfaces list.
CALayerDelegate
WARNING: CALayerDelegate is a stub. To generate bindings for this class, include CALayerDelegate in your config's objc-protocols list.
CAMediaTiming
WARNING: CAMediaTiming is a stub. To generate bindings for this class, include CAMediaTiming in your config's objc-protocols list.
CIColor
WARNING: CIColor is a stub. To generate bindings for this class, include CIColor in your config's objc-interfaces list.
CIImage
WARNING: CIImage is a stub. To generate bindings for this class, include CIImage in your config's objc-interfaces list.
NSExtensionContext
WARNING: NSExtensionContext is a stub. To generate bindings for this class, include NSExtensionContext in your config's objc-interfaces list.
NSExtensionRequestHandling
WARNING: NSExtensionRequestHandling is a stub. To generate bindings for this class, include NSExtensionRequestHandling in your config's objc-protocols list.
NSLayoutAnchor
WARNING: NSLayoutAnchor is a stub. To generate bindings for this class, include NSLayoutAnchor in your config's objc-interfaces list.
NSLayoutConstraint
NSLayoutConstraint
NSLayoutDimension
WARNING: NSLayoutDimension is a stub. To generate bindings for this class, include NSLayoutDimension in your config's objc-interfaces list.
NSLayoutXAxisAnchor
WARNING: NSLayoutXAxisAnchor is a stub. To generate bindings for this class, include NSLayoutXAxisAnchor in your config's objc-interfaces list.
NSLayoutYAxisAnchor
WARNING: NSLayoutYAxisAnchor is a stub. To generate bindings for this class, include NSLayoutYAxisAnchor in your config's objc-interfaces list.
NSToolbar
WARNING: NSToolbar is a stub. To generate bindings for this class, include NSToolbar in your config's objc-interfaces list.
NSUndoManager
WARNING: NSUndoManager is a stub. To generate bindings for this class, include NSUndoManager in your config's objc-interfaces list.
NSUserActivity
WARNING: NSUserActivity is a stub. To generate bindings for this class, include NSUserActivity in your config's objc-interfaces list.
UIAction
UIAction
UIActivityIndicatorView
UIActivityIndicatorView
UIActivityItemsConfigurationProviding
WARNING: UIActivityItemsConfigurationProviding is a stub. To generate bindings for this class, include UIActivityItemsConfigurationProviding in your config's objc-protocols list.
UIAlertAction
UIAlertAction
UIAlertController
UIAlertController
UIAppearance
WARNING: UIAppearance is a stub. To generate bindings for this class, include UIAppearance in your config's objc-protocols list.
UIAppearanceContainer
WARNING: UIAppearanceContainer is a stub. To generate bindings for this class, include UIAppearanceContainer in your config's objc-protocols list.
UIApplication
UIApplication
UIApplicationDelegate
WARNING: UIApplicationDelegate is a stub. To generate bindings for this class, include UIApplicationDelegate in your config's objc-protocols list.
UIBarAppearance
UIBarAppearance
UIBarButtonItem
UIBarButtonItem
UIBarButtonItemAppearance
UIBarButtonItemAppearance
UIBarButtonItemGroup$1
UIBarButtonItemGroup
UIBarButtonItemStateAppearance
WARNING: UIBarButtonItemStateAppearance is a stub. To generate bindings for this class, include UIBarButtonItemStateAppearance in your config's objc-interfaces list.
UIBarItem
UIBarItem
UIBezierPath
WARNING: UIBezierPath is a stub. To generate bindings for this class, include UIBezierPath in your config's objc-interfaces list.
UIBlurEffect
WARNING: UIBlurEffect is a stub. To generate bindings for this class, include UIBlurEffect in your config's objc-interfaces list.
UIButton
UIButton
UIButtonConfiguration
WARNING: UIButtonConfiguration is a stub. To generate bindings for this class, include UIButtonConfiguration in your config's objc-interfaces list.
UIColor
UIColor
UICommand
WARNING: UICommand is a stub. To generate bindings for this class, include UICommand in your config's objc-interfaces list.
UIContentContainer
WARNING: UIContentContainer is a stub. To generate bindings for this class, include UIContentContainer in your config's objc-protocols list.
UIContentSizeCategoryAdjusting
WARNING: UIContentSizeCategoryAdjusting is a stub. To generate bindings for this class, include UIContentSizeCategoryAdjusting in your config's objc-protocols list.
UIContextMenuConfiguration
WARNING: UIContextMenuConfiguration is a stub. To generate bindings for this class, include UIContextMenuConfiguration in your config's objc-interfaces list.
UIContextMenuInteraction
WARNING: UIContextMenuInteraction is a stub. To generate bindings for this class, include UIContextMenuInteraction in your config's objc-interfaces list.
UIControl
UIControl
UICoordinateSpace
WARNING: UICoordinateSpace is a stub. To generate bindings for this class, include UICoordinateSpace in your config's objc-protocols list.
UIDynamicItem
WARNING: UIDynamicItem is a stub. To generate bindings for this class, include UIDynamicItem in your config's objc-protocols list.
UIEvent
WARNING: UIEvent is a stub. To generate bindings for this class, include UIEvent in your config's objc-interfaces list.
UIFocusAnimationCoordinator
WARNING: UIFocusAnimationCoordinator is a stub. To generate bindings for this class, include UIFocusAnimationCoordinator in your config's objc-interfaces list.
UIFocusEffect
WARNING: UIFocusEffect is a stub. To generate bindings for this class, include UIFocusEffect in your config's objc-interfaces list.
UIFocusEnvironment
WARNING: UIFocusEnvironment is a stub. To generate bindings for this class, include UIFocusEnvironment in your config's objc-protocols list.
UIFocusItem
WARNING: UIFocusItem is a stub. To generate bindings for this class, include UIFocusItem in your config's objc-protocols list.
UIFocusItemContainer
WARNING: UIFocusItemContainer is a stub. To generate bindings for this class, include UIFocusItemContainer in your config's objc-protocols list.
UIFocusItemScrollableContainer
WARNING: UIFocusItemScrollableContainer is a stub. To generate bindings for this class, include UIFocusItemScrollableContainer in your config's objc-protocols list.
UIFocusMovementHint
WARNING: UIFocusMovementHint is a stub. To generate bindings for this class, include UIFocusMovementHint in your config's objc-interfaces list.
UIFocusUpdateContext
WARNING: UIFocusUpdateContext is a stub. To generate bindings for this class, include UIFocusUpdateContext in your config's objc-interfaces list.
UIFont
UIFont
UIFontDescriptor
WARNING: UIFontDescriptor is a stub. To generate bindings for this class, include UIFontDescriptor in your config's objc-interfaces list.
UIGestureRecognizer
WARNING: UIGestureRecognizer is a stub. To generate bindings for this class, include UIGestureRecognizer in your config's objc-interfaces list.
UIImage
UIImage
UIImageConfiguration
WARNING: UIImageConfiguration is a stub. To generate bindings for this class, include UIImageConfiguration in your config's objc-interfaces list.
UIImageSymbolConfiguration
WARNING: UIImageSymbolConfiguration is a stub. To generate bindings for this class, include UIImageSymbolConfiguration in your config's objc-interfaces list.
UIImageView
UIImageView
UIInputViewController
WARNING: UIInputViewController is a stub. To generate bindings for this class, include UIInputViewController in your config's objc-interfaces list.
UIInteraction
WARNING: UIInteraction is a stub. To generate bindings for this class, include UIInteraction in your config's objc-protocols list.
UIKeyboardLayoutGuide
WARNING: UIKeyboardLayoutGuide is a stub. To generate bindings for this class, include UIKeyboardLayoutGuide in your config's objc-interfaces list.
UIKeyCommand$1
WARNING: UIKeyCommand$1 is a stub. To generate bindings for this class, include UIKeyCommand in your config's objc-interfaces list.
UIKeyInput
WARNING: UIKeyInput is a stub. To generate bindings for this class, include UIKeyInput in your config's objc-protocols list.
UILabel
UILabel
UILayoutGuide
WARNING: UILayoutGuide is a stub. To generate bindings for this class, include UILayoutGuide in your config's objc-interfaces list.
UILayoutSupport$1
WARNING: UILayoutSupport$1 is a stub. To generate bindings for this class, include UILayoutSupport in your config's objc-protocols list.
UILocalNotification
WARNING: UILocalNotification is a stub. To generate bindings for this class, include UILocalNotification in your config's objc-interfaces list.
UIMenu
UIMenu
UIMenuBuilder
WARNING: UIMenuBuilder is a stub. To generate bindings for this class, include UIMenuBuilder in your config's objc-protocols list.
UIMenuElement
UIMenuElement
UIMotionEffect
WARNING: UIMotionEffect is a stub. To generate bindings for this class, include UIMotionEffect in your config's objc-interfaces list.
UINavigationBar
WARNING: UINavigationBar is a stub. To generate bindings for this class, include UINavigationBar in your config's objc-interfaces list.
UINavigationBarAppearance
UINavigationBarAppearance
UINavigationController
UINavigationController
UINavigationControllerDelegate
WARNING: UINavigationControllerDelegate is a stub. To generate bindings for this class, include UINavigationControllerDelegate in your config's objc-protocols list.
UINavigationItem
UINavigationItem
UIPageControl
UIPageControl
UIPanGestureRecognizer
WARNING: UIPanGestureRecognizer is a stub. To generate bindings for this class, include UIPanGestureRecognizer in your config's objc-interfaces list.
UIPinchGestureRecognizer
WARNING: UIPinchGestureRecognizer is a stub. To generate bindings for this class, include UIPinchGestureRecognizer in your config's objc-interfaces list.
UIPointerEffect
WARNING: UIPointerEffect is a stub. To generate bindings for this class, include UIPointerEffect in your config's objc-interfaces list.
UIPointerLockState
WARNING: UIPointerLockState is a stub. To generate bindings for this class, include UIPointerLockState in your config's objc-interfaces list.
UIPointerShape
WARNING: UIPointerShape is a stub. To generate bindings for this class, include UIPointerShape in your config's objc-interfaces list.
UIPointerStyle
WARNING: UIPointerStyle is a stub. To generate bindings for this class, include UIPointerStyle in your config's objc-interfaces list.
UIPopoverPresentationController
WARNING: UIPopoverPresentationController is a stub. To generate bindings for this class, include UIPopoverPresentationController in your config's objc-interfaces list.
UIPresentationController$1
WARNING: UIPresentationController$1 is a stub. To generate bindings for this class, include UIPresentationController in your config's objc-interfaces list.
UIPressesEvent
WARNING: UIPressesEvent is a stub. To generate bindings for this class, include UIPressesEvent in your config's objc-interfaces list.
UIProgressView
UIProgressView
UIRefreshControl
WARNING: UIRefreshControl is a stub. To generate bindings for this class, include UIRefreshControl in your config's objc-interfaces list.
UIResponder
UIResponder
UIResponderStandardEditActions
WARNING: UIResponderStandardEditActions is a stub. To generate bindings for this class, include UIResponderStandardEditActions in your config's objc-protocols list.
UIScene
UIScene
UISceneActivationConditions
WARNING: UISceneActivationConditions is a stub. To generate bindings for this class, include UISceneActivationConditions in your config's objc-interfaces list.
UISceneActivationRequestOptions
WARNING: UISceneActivationRequestOptions is a stub. To generate bindings for this class, include UISceneActivationRequestOptions in your config's objc-interfaces list.
UISceneConnectionOptions
WARNING: UISceneConnectionOptions is a stub. To generate bindings for this class, include UISceneConnectionOptions in your config's objc-interfaces list.
UISceneDelegate
WARNING: UISceneDelegate is a stub. To generate bindings for this class, include UISceneDelegate in your config's objc-protocols list.
UISceneDestructionRequestOptions
WARNING: UISceneDestructionRequestOptions is a stub. To generate bindings for this class, include UISceneDestructionRequestOptions in your config's objc-interfaces list.
UISceneOpenExternalURLOptions
WARNING: UISceneOpenExternalURLOptions is a stub. To generate bindings for this class, include UISceneOpenExternalURLOptions in your config's objc-interfaces list.
UISceneSession
WARNING: UISceneSession is a stub. To generate bindings for this class, include UISceneSession in your config's objc-interfaces list.
UISceneSizeRestrictions
WARNING: UISceneSizeRestrictions is a stub. To generate bindings for this class, include UISceneSizeRestrictions in your config's objc-interfaces list.
UIScreen
UIScreen
UIScrollView
UIScrollView
UIScrollViewDelegate
WARNING: UIScrollViewDelegate is a stub. To generate bindings for this class, include UIScrollViewDelegate in your config's objc-protocols list.
UISearchController
WARNING: UISearchController is a stub. To generate bindings for this class, include UISearchController in your config's objc-interfaces list.
UISearchDisplayController
WARNING: UISearchDisplayController is a stub. To generate bindings for this class, include UISearchDisplayController in your config's objc-interfaces list.
UISheetPresentationController
WARNING: UISheetPresentationController is a stub. To generate bindings for this class, include UISheetPresentationController in your config's objc-interfaces list.
UISlider
UISlider
UIStackView
UIStackView
UIStateRestoring
WARNING: UIStateRestoring is a stub. To generate bindings for this class, include UIStateRestoring in your config's objc-protocols list.
UIStoryboard
WARNING: UIStoryboard is a stub. To generate bindings for this class, include UIStoryboard in your config's objc-interfaces list.
UIStoryboardSegue
WARNING: UIStoryboardSegue is a stub. To generate bindings for this class, include UIStoryboardSegue in your config's objc-interfaces list.
UIStoryboardUnwindSegueSource
WARNING: UIStoryboardUnwindSegueSource is a stub. To generate bindings for this class, include UIStoryboardUnwindSegueSource in your config's objc-interfaces list.
UISwitch
UISwitch
UITabBar
UITabBar
UITabBarAppearance
UITabBarAppearance
UITabBarController
! UITabBarController manages a button bar and transition view, for an application with multiple top-level modes.
UITabBarControllerDelegate
WARNING: UITabBarControllerDelegate is a stub. To generate bindings for this class, include UITabBarControllerDelegate in your config's objc-protocols list.
UITabBarDelegate
WARNING: UITabBarDelegate is a stub. To generate bindings for this class, include UITabBarDelegate in your config's objc-protocols list.
UITabBarItem
UITabBarItem
UITabBarItemAppearance
WARNING: UITabBarItemAppearance is a stub. To generate bindings for this class, include UITabBarItemAppearance in your config's objc-interfaces list.
UITapGestureRecognizer
WARNING: UITapGestureRecognizer is a stub. To generate bindings for this class, include UITapGestureRecognizer in your config's objc-interfaces list.
UITextField
UITextField
UITextFieldDelegate
WARNING: UITextFieldDelegate is a stub. To generate bindings for this class, include UITextFieldDelegate in your config's objc-protocols list.
UITextInput
WARNING: UITextInput is a stub. To generate bindings for this class, include UITextInput in your config's objc-protocols list.
UITextInputAssistantItem
WARNING: UITextInputAssistantItem is a stub. To generate bindings for this class, include UITextInputAssistantItem in your config's objc-interfaces list.
UITextInputDelegate
WARNING: UITextInputDelegate is a stub. To generate bindings for this class, include UITextInputDelegate in your config's objc-protocols list.
UITextInputMode
WARNING: UITextInputMode is a stub. To generate bindings for this class, include UITextInputMode in your config's objc-interfaces list.
UITextInputPasswordRules
WARNING: UITextInputPasswordRules is a stub. To generate bindings for this class, include UITextInputPasswordRules in your config's objc-interfaces list.
UITextInputTokenizer
WARNING: UITextInputTokenizer is a stub. To generate bindings for this class, include UITextInputTokenizer in your config's objc-protocols list.
UITextInputTraits
WARNING: UITextInputTraits is a stub. To generate bindings for this class, include UITextInputTraits in your config's objc-protocols list.
UITextPlaceholder
WARNING: UITextPlaceholder is a stub. To generate bindings for this class, include UITextPlaceholder in your config's objc-interfaces list.
UITextPosition
WARNING: UITextPosition is a stub. To generate bindings for this class, include UITextPosition in your config's objc-interfaces list.
UITextRange
WARNING: UITextRange is a stub. To generate bindings for this class, include UITextRange in your config's objc-interfaces list.
UITitlebar
UITitlebar
UIToolbar
WARNING: UIToolbar is a stub. To generate bindings for this class, include UIToolbar in your config's objc-interfaces list.
UIToolTipInteraction
WARNING: UIToolTipInteraction is a stub. To generate bindings for this class, include UIToolTipInteraction in your config's objc-interfaces list.
UITouch
WARNING: UITouch is a stub. To generate bindings for this class, include UITouch in your config's objc-interfaces list.
UITraitCollection
WARNING: UITraitCollection is a stub. To generate bindings for this class, include UITraitCollection in your config's objc-interfaces list.
UITraitEnvironment
WARNING: UITraitEnvironment is a stub. To generate bindings for this class, include UITraitEnvironment in your config's objc-protocols list.
UIUserActivityRestoring
WARNING: UIUserActivityRestoring is a stub. To generate bindings for this class, include UIUserActivityRestoring in your config's objc-protocols list.
UIUserNotificationSettings$1
WARNING: UIUserNotificationSettings$1 is a stub. To generate bindings for this class, include UIUserNotificationSettings in your config's objc-interfaces list.
UIView
UIView
UIViewController
UIViewController
UIViewControllerPreviewing
WARNING: UIViewControllerPreviewing is a stub. To generate bindings for this class, include UIViewControllerPreviewing in your config's objc-protocols list.
UIViewControllerPreviewingDelegate
WARNING: UIViewControllerPreviewingDelegate is a stub. To generate bindings for this class, include UIViewControllerPreviewingDelegate in your config's objc-protocols list.
UIViewControllerRestoration
WARNING: UIViewControllerRestoration is a stub. To generate bindings for this class, include UIViewControllerRestoration in your config's objc-protocols list.
UIViewControllerTransitionCoordinator
WARNING: UIViewControllerTransitionCoordinator is a stub. To generate bindings for this class, include UIViewControllerTransitionCoordinator in your config's objc-protocols list.
UIViewControllerTransitioningDelegate
WARNING: UIViewControllerTransitioningDelegate is a stub. To generate bindings for this class, include UIViewControllerTransitioningDelegate in your config's objc-protocols list.
UIWindow
UIWindow
UIWindowScene
UIWindowScene

Extensions

ActivityContinuation on UIResponder
ActivityContinuation
DeprecatedAnimations on UIView
DeprecatedAnimations
DynamicColors on UIColor
DynamicColors
Interactions on UIView
Interactions
NSExtensionAdditions on UIViewController
NSExtensionAdditions
NSIdentifier on NSLayoutConstraint
NSIdentifier
NSItemProvider on UIImage
NSItemProvider
NSLayoutConstraint$Methods on NSLayoutConstraint
NSToolbarAdditions on UIWindowScene
NSToolbarAdditions
ObjCBlock_ffiVoid$CallExtension on ObjCBlock<Void Function()>
Call operator for objc.ObjCBlock<ffi.Void Function()>.
ObjCBlock_ffiVoid_bool$CallExtension on ObjCBlock<Void Function(Bool)>
Call operator for objc.ObjCBlock<ffi.Void Function(ffi.Bool)>.
ObjCBlock_ffiVoid_NSData_NSError$CallExtension on ObjCBlock<Void Function(NSData?, NSError?)>
Call operator for objc.ObjCBlock<ffi.Void Function(objc.NSData?, objc.NSError?)>.
ObjCBlock_ffiVoid_NSError$1$CallExtension on ObjCBlock<Void Function(NSError?)>
Call operator for objc.ObjCBlock<ffi.Void Function(objc.NSError?)>.
ObjCBlock_ffiVoid_NSError$CallExtension on ObjCBlock<Void Function(NSError)>
Call operator for objc.ObjCBlock<ffi.Void Function(objc.NSError)>.
ObjCBlock_ffiVoid_UIAction$CallExtension on ObjCBlock<Void Function(UIAction)>
Call operator for objc.ObjCBlock<ffi.Void Function(UIAction)>.
ObjCBlock_ffiVoid_UIAction_objcObjCObjectImpl_objcObjCSelector_UIControlEvents_bool$CallExtension on ObjCBlock<Void Function(UIAction?, Pointer<ObjCObjectImpl>?, Pointer<ObjCSelector>, UnsignedLong, Pointer<Bool>)>
Call operator for objc.ObjCBlock<ffi.Void Function(UIAction?, ffi.Pointer<objc.ObjCObjectImpl>?, ffi.Pointer<objc.ObjCSelector>, ffi.UnsignedLong, ffi.Pointer<ffi.Bool>)>.
ObjCBlock_ffiVoid_UIAlertAction$CallExtension on ObjCBlock<Void Function(UIAlertAction)>
Call operator for objc.ObjCBlock<ffi.Void Function(UIAlertAction)>.
ObjCBlock_ffiVoid_UIButton$CallExtension on ObjCBlock<Void Function(UIButton)>
Call operator for objc.ObjCBlock<ffi.Void Function(UIButton)>.
ObjCBlock_ffiVoid_UITextField$CallExtension on ObjCBlock<Void Function(UITextField)>
Call operator for objc.ObjCBlock<ffi.Void Function(UITextField)>.
ObjCBlock_NSDictionary_NSDictionary$CallExtension on ObjCBlock<NSDictionary Function(NSDictionary)>
Call operator for objc.ObjCBlock<objc.NSDictionary Function(objc.NSDictionary)>.
ObjCBlock_UIColor_UITraitCollection$CallExtension on ObjCBlock<UIColor Function(UITraitCollection)>
Call operator for objc.ObjCBlock<UIColor Function(UITraitCollection)>.
ObjCBlock_UIPointerStyle_UIButton_UIPointerEffect_UIPointerShape$CallExtension on ObjCBlock<UIPointerStyle? Function(UIButton, UIPointerEffect, UIPointerShape)>
Call operator for objc.ObjCBlock<UIPointerStyle? Function(UIButton, UIPointerEffect, UIPointerShape)>.
PointerLockState on UIScene
PointerLockState
PreconfiguredSystemImages on UIImage
PreconfiguredSystemImages
UIAction$Methods on UIAction
UIActivityIndicatorView$Methods on UIActivityIndicatorView
UIAlertAction$Methods on UIAlertAction
UIAlertController$Methods on UIAlertController
UIAlternateApplicationIcons on UIApplication
UIAlternateApplicationIcons
UIApplication$Methods on UIApplication
UIApplicationDeprecated on UIApplication
UIApplicationDeprecated
UIBarAppearance$Methods on UIBarAppearance
UIBarButtonItem$Methods on UIBarButtonItem
UIBarButtonItemAppearance$Methods on UIBarButtonItemAppearance
UIBarButtonItemGroup on UIBarButtonItem
UIBarButtonItemGroup
UIBarButtonItemGroup$1$Methods on UIBarButtonItemGroup$1
UIBarItem$Methods on UIBarItem
UIButton$Methods on UIButton
UICaptureTextFromCameraSupporting on UIResponder
UICaptureTextFromCameraSupporting
UICaptureTextFromCameraSupporting$1 on UIAction
UICaptureTextFromCameraSupporting
UIColor$Methods on UIColor
UIColorNamedColors on UIColor
UIColorNamedColors
UIColorSystemColors on UIColor
UIColorSystemColors
UIConstraintBasedCompatibility on UIView
UIConstraintBasedCompatibility
UIConstraintBasedLayoutCoreMethods on UIViewController
UIConstraintBasedLayoutCoreMethods
UIConstraintBasedLayoutCoreMethods$1 on UIView
UIConstraintBasedLayoutCoreMethods
UIConstraintBasedLayoutDebugging on UIView
UIConstraintBasedLayoutDebugging
UIConstraintBasedLayoutFittingSize on UIView
UIConstraintBasedLayoutFittingSize
UIConstraintBasedLayoutInstallingConstraints on UIView
UIConstraintBasedLayoutInstallingConstraints
UIConstraintBasedLayoutLayering on UIView
UIConstraintBasedLayoutLayering
UIContainerViewControllerCallbacks on UIViewController
UIContainerViewControllerCallbacks
UIContainerViewControllerProtectedMethods on UIViewController
UIContainerViewControllerProtectedMethods
UIContentSizeCategoryLimit on UIView
UIContentSizeCategoryLimit
UIControl$Methods on UIControl
UIFont$Methods on UIFont
UIFontSystemFonts on UIFont
UIFontSystemFonts
UIHomeIndicatorAutoHidden on UIViewController
UIHomeIndicatorAutoHidden
UIImage$Methods on UIImage
UIImageDeprecated on UIImage
UIImageDeprecated
UIImageView$Methods on UIImageView
UIInteractionStateRestorable on UITextField
UIInteractionStateRestorable
UIKeyCommand on UIViewController
UIKeyCommand
UIKitColorExtension on Color
UILabel$Methods on UILabel
UILayoutGuideSupport on UIView
UILayoutGuideSupport
UILayoutSupport on UIViewController
UILayoutSupport
UILocalNotifications on UIApplication
UILocalNotifications
UIMenu$Methods on UIMenu
UIMenuElement$Methods on UIMenuElement
UINavigationBarAppearance$Methods on UINavigationBarAppearance
UINavigationController$Methods on UINavigationController
UINavigationControllerContextualToolbarItems on UIViewController
UINavigationControllerContextualToolbarItems
UINavigationControllerItem on UIViewController
UINavigationControllerItem
UINavigationItem$Methods on UINavigationItem
UINewsstand on UIApplication
UINewsstand
UINSItemProvider on UIColor
UINSItemProvider
UIPageControl$Methods on UIPageControl
UIPerformsActions on UIViewController
UIPerformsActions
UIPointerLockSupport on UIViewController
UIPointerLockSupport
UIPresentationController on UIViewController
UIPresentationController
UIProgressView$Methods on UIProgressView
UIRemoteControlEvents on UIApplication
UIRemoteControlEvents
UIRemoteNotifications on UIApplication
UIRemoteNotifications
UIResponder$Methods on UIResponder
UIResponderInputViewAdditions on UIResponder
UIResponderInputViewAdditions
UIResponderKeyCommands on UIResponder
UIResponderKeyCommands
UIScene$Methods on UIScene
UIScreen$Methods on UIScreen
UIScreenEdgesDeferringSystemGestures on UIViewController
UIScreenEdgesDeferringSystemGestures
UIScrollView$Methods on UIScrollView
UISearchDisplayControllerSupport on UIViewController
UISearchDisplayControllerSupport
UIShortcutItems on UIApplication
UIShortcutItems
UISlider$Methods on UISlider
UISnapshotting on UIView
UISnapshotting
UIStackView$Methods on UIStackView
UIStateRestoration on UIViewController
UIStateRestoration
UIStateRestoration$1 on UIView
UIStateRestoration
UIStateRestoration$2 on UIApplication
UIStateRestoration
UISwitch$Methods on UISwitch
UITabBar$Methods on UITabBar
UITabBarAppearance$Methods on UITabBarAppearance
UITabBarController$Methods on UITabBarController
UITabBarControllerItem on UIViewController
UITabBarControllerItem
UITabBarItem$Methods on UITabBarItem
UITextField$Methods on UITextField
UITitlebar$Methods on UITitlebar
UIUserNotificationSettings on UIApplication
UIUserNotificationSettings
UIView$Methods on UIView
UIViewAnimation on UIView
UIViewAnimation
UIViewAnimationWithBlocks on UIView
UIViewAnimationWithBlocks
UIViewController$Methods on UIViewController
UIViewControllerEditing on UIViewController
UIViewControllerEditing
UIViewControllerPreviewingRegistration on UIViewController
UIViewControllerPreviewingRegistration
UIViewControllerRotation on UIViewController
UIViewControllerRotation
UIViewControllerTransitionCoordinator$1 on UIViewController
UIViewControllerTransitionCoordinator
UIViewControllerTransitioning on UIViewController
UIViewControllerTransitioning
UIViewGeometry on UIView
UIViewGeometry
UIViewGestureRecognizers on UIView
UIViewGestureRecognizers
UIViewHierarchy on UIView
UIViewHierarchy
UIViewKeyframeAnimations on UIView
UIViewKeyframeAnimations
UIViewLayoutConstraintCreation on UIView
UIViewLayoutConstraintCreation
UIViewMotionEffects on UIView
UIViewMotionEffects
UIViewRendering on UIView
UIViewRendering
UIViewUITextField on UIView
UITextField
UIWindow$Methods on UIWindow
UIWindowScene$Methods on UIWindowScene
unnamed on UIViewController
unnamed$1 on UIButton
UserInterfaceStyle on UIView
UserInterfaceStyle

Functions

createCGRect(double x, double y, double width, double height) → CGRect
Helper to create CGRect.
createCGSize(double width, double height) → CGSize
getKeyWindow([UIWindowScene? scene]) UIWindow?
Returns the key window for scene, or a best-effort key window from the most relevant foreground window scene when scene is omitted.

Typedefs

Dartinstancetype = ObjCObject
instancetype = Pointer<ObjCObjectImpl>