CAConstraintAttribute enum
Values
- kCAConstraintMinX → const CAConstraintAttribute
-
const CAConstraintAttribute(0) - kCAConstraintMidX → const CAConstraintAttribute
-
const CAConstraintAttribute(1) - kCAConstraintMaxX → const CAConstraintAttribute
-
const CAConstraintAttribute(2) - kCAConstraintWidth → const CAConstraintAttribute
-
const CAConstraintAttribute(3) - kCAConstraintMinY → const CAConstraintAttribute
-
const CAConstraintAttribute(4) - kCAConstraintMidY → const CAConstraintAttribute
-
const CAConstraintAttribute(5) - kCAConstraintMaxY → const CAConstraintAttribute
-
const CAConstraintAttribute(6) - kCAConstraintHeight → const CAConstraintAttribute
-
const CAConstraintAttribute(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → CAConstraintAttribute
Constants
-
values
→ const List<
CAConstraintAttribute> - A constant List of the values in this enum, in order of their declaration.