NSDragOperation class sealed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- NSDragOperationAll → const int
- NSDragOperationAll_Obsolete → const int
- NSDragOperationCopy → const int
- NSDragOperationDelete → const int
- NSDragOperationEvery → const int
- NSDragOperationGeneric → const int
- NSDragOperationLink → const int
- NSDragOperationMove → const int
- NSDragOperationNone → const int
- NSDragOperationPrivate → const int