NSLayoutConstraint extension type
NSLayoutConstraint
- on
-
- ObjCObject
- Available extensions
Constructors
- NSLayoutConstraint()
-
Returns a new instance of NSLayoutConstraint constructed with the default
newmethod. - NSLayoutConstraint.as(ObjCObject other)
-
Constructs a NSLayoutConstraint that points to the same underlying object as
other. -
NSLayoutConstraint.fromPointer(Pointer<
ObjCObjectImpl> other, {bool retain = false, bool release = false}) - Constructs a NSLayoutConstraint that wraps the given raw object pointer.
Properties
- constant ↔ double
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
constantgetter/setter pair - firstAnchor → NSLayoutAnchor
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
firstAnchorno setter - firstAttribute → NSLayoutAttribute
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
firstAttributeno setter - firstItem → ObjCObject?
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
firstItemno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ NSString?
-
Available on NSLayoutConstraint, provided by the NSIdentifier extension
identifiergetter/setter pair - isActive ↔ bool
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
isActivegetter/setter pair - multiplier → double
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
multiplierno setter - object$ → ObjCObject
-
final
- priority ↔ double
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
prioritygetter/setter pair - ref → ObjCObjectRef
-
finalinherited
- relation → NSLayoutRelation
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
relationno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondAnchor → NSLayoutAnchor?
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
secondAnchorno setter - secondAttribute → NSLayoutAttribute
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
secondAttributeno setter - secondItem → ObjCObject?
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
secondItemno setter - shouldBeArchived ↔ bool
-
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
shouldBeArchivedgetter/setter pair
Methods
-
init(
) → NSLayoutConstraint -
Available on NSLayoutConstraint, provided by the NSLayoutConstraint$Methods extension
init -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
activateConstraints(
NSArray constraints) → void - activateConstraints:
-
alloc(
) → NSLayoutConstraint - alloc
-
allocWithZone(
Pointer< NSZone> zone) → NSLayoutConstraint - allocWithZone:
-
constraintsWithVisualFormat(
NSString format, {required int options, NSDictionary? metrics, required NSDictionary views}) → NSArray - constraintsWithVisualFormat:options:metrics:views:
-
constraintWithItem(
ObjCObject view1, {required NSLayoutAttribute attribute, ObjCObject? toItem, required NSLayoutAttribute attribute$1, required double multiplier, required double constant}) → NSLayoutConstraint - constraintWithItem:attribute:relatedBy:toItem:attribute:multiplier:constant:
-
deactivateConstraints(
NSArray constraints) → void - deactivateConstraints:
-
isA(
ObjCObject obj) → bool -
Returns whether
objis an instance of NSLayoutConstraint. -
new$(
) → NSLayoutConstraint - new