keyWindow property

  1. @Deprecated('Should not be used for applications that support multiple scenes as it returns a key window across all connected scenes')
UIWindow? get keyWindow

keyWindow

Implementation

@Deprecated(
  'Should not be used for applications that support multiple scenes as it returns a key window across all connected scenes',
)
UIWindow? get keyWindow {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIApplication.keyWindow', iOS: (false, (2, 0, 0)));
  final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_keyWindow);
  return $ret.address == 0 ? null : UIWindow.fromPointer($ret, retain: true, release: true);
}