setMinimumBackgroundFetchInterval method

  1. @Deprecated('Use a BGAppRefreshTask in the BackgroundTasks framework instead')
void setMinimumBackgroundFetchInterval(
  1. double minimumBackgroundFetchInterval
)

! The system guarantees that it will not wake up your application for a background fetch more frequently than the interval provided. Set to UIApplicationBackgroundFetchIntervalMinimum to be woken as frequently as the system desires, or to UIApplicationBackgroundFetchIntervalNever (the default) to never be woken for a background fetch.

This setter will have no effect unless your application has the "fetch" UIBackgroundMode. See the UIApplicationDelegate method application:performFetchWithCompletionHandler: for more.

Implementation

@Deprecated('Use a BGAppRefreshTask in the BackgroundTasks framework instead')
void setMinimumBackgroundFetchInterval(double minimumBackgroundFetchInterval) {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIApplication.setMinimumBackgroundFetchInterval:', iOS: (false, (7, 0, 0)));
  _objc_msgSend_hwm8nu(_$$ref.pointer, _sel_setMinimumBackgroundFetchInterval_, minimumBackgroundFetchInterval);
}