backgroundEffect property
UIBlurEffect?
get
backgroundEffect
A specific blur effect to use for the bar background. This effect is composited first when constructing the bar's background.
Implementation
UIBlurEffect? get backgroundEffect {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIBarAppearance.backgroundEffect', iOS: (false, (13, 0, 0)));
final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_backgroundEffect);
return $ret.address == 0 ? null : UIBlurEffect.fromPointer($ret, retain: true, release: true);
}
set
backgroundEffect
(UIBlurEffect? value)
A specific blur effect to use for the bar background. This effect is composited first when constructing the bar's background.
Implementation
set backgroundEffect(UIBlurEffect? value) {
final _$$ref = object$.ref;
final _$$ref$1 = value?.ref;
objc.checkOsVersionInternal('UIBarAppearance.setBackgroundEffect:', iOS: (false, (13, 0, 0)));
_objc_msgSend_xtuoz7(_$$ref.pointer, _sel_setBackgroundEffect_, _$$ref$1?.pointer ?? ffi.nullptr);
}