UIBarButtonItemAppearance extension type
UIBarButtonItemAppearance
- on
-
- ObjCObject
- Available extensions
Constructors
- UIBarButtonItemAppearance()
-
Returns a new instance of UIBarButtonItemAppearance constructed with the default
newmethod. - UIBarButtonItemAppearance.as(ObjCObject other)
-
Constructs a UIBarButtonItemAppearance that points to the same underlying object as
other. -
UIBarButtonItemAppearance.fromPointer(Pointer<
ObjCObjectImpl> other, {bool retain = false, bool release = false}) - Constructs a UIBarButtonItemAppearance that wraps the given raw object pointer.
Properties
- disabled → UIBarButtonItemStateAppearance
-
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
The appearance when the bar button item is in the disabled control state. If unspecified, then synthesized from the normal state.no setter - focused → UIBarButtonItemStateAppearance
-
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
The appearance when the bar button item is in the focused control state. If unspecified, then synthesized from the highlighted state.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- highlighted → UIBarButtonItemStateAppearance
-
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
The appearance when the bar button item is in the highlighted control state. If unspecified, then synthesized from the normal state.no setter - normal → UIBarButtonItemStateAppearance
-
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
The appearance when the bar button item is in the normal control state.no setter - object$ → ObjCObject
-
final
- ref → ObjCObjectRef
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configureWithDefaultForStyle(
UIBarButtonItemStyle style) → void -
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
Reset this appearance to that of a given style. -
copy(
) → UIBarButtonItemAppearance -
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
copy -
encodeWithCoder(
NSCoder coder) → void -
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
encodeWithCoder: -
init(
) → UIBarButtonItemAppearance -
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
init -
initWithCoder(
NSCoder coder) → UIBarButtonItemAppearance? -
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
initWithCoder: -
initWithStyle(
UIBarButtonItemStyle style) → UIBarButtonItemAppearance -
Available on UIBarButtonItemAppearance, provided by the UIBarButtonItemAppearance$Methods extension
Construct an appearance with default values for the given style. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
alloc(
) → UIBarButtonItemAppearance - alloc
-
allocWithZone(
Pointer< NSZone> zone) → UIBarButtonItemAppearance - allocWithZone:
-
getSupportsSecureCoding(
) → bool - supportsSecureCoding
-
isA(
ObjCObject obj) → bool -
Returns whether
objis an instance of UIBarButtonItemAppearance. -
new$(
) → UIBarButtonItemAppearance - new