adjustsImageWhenDisabled property

  1. @Deprecated('This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler')
bool get adjustsImageWhenDisabled

adjustsImageWhenDisabled

Implementation

@Deprecated(
  'This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler',
)
bool get adjustsImageWhenDisabled {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIButton.adjustsImageWhenDisabled', iOS: (false, (2, 0, 0)));
  return _objc_msgSend_91o635(_$$ref.pointer, _sel_adjustsImageWhenDisabled);
}
  1. @Deprecated('This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler')
set adjustsImageWhenDisabled (bool value)

setAdjustsImageWhenDisabled:

Implementation

@Deprecated(
  'This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler',
)
set adjustsImageWhenDisabled(bool value) {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIButton.setAdjustsImageWhenDisabled:', iOS: (false, (2, 0, 0)));
  _objc_msgSend_1s56lr9(_$$ref.pointer, _sel_setAdjustsImageWhenDisabled_, value);
}