automaticallyUpdatesConfiguration property
bool
get
automaticallyUpdatesConfiguration
When YES, the button will automatically call -updatedConfigurationForButton: on its configuration when the button's state changes, and apply the updated configuration to the button. The default value is YES.
Implementation
bool get automaticallyUpdatesConfiguration {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.automaticallyUpdatesConfiguration', iOS: (false, (15, 0, 0)));
return _objc_msgSend_91o635(_$$ref.pointer, _sel_automaticallyUpdatesConfiguration);
}
set
automaticallyUpdatesConfiguration
(bool value)
When YES, the button will automatically call -updatedConfigurationForButton: on its configuration when the button's state changes, and apply the updated configuration to the button. The default value is YES.
Implementation
set automaticallyUpdatesConfiguration(bool value) {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.setAutomaticallyUpdatesConfiguration:', iOS: (false, (15, 0, 0)));
_objc_msgSend_1s56lr9(_$$ref.pointer, _sel_setAutomaticallyUpdatesConfiguration_, value);
}