changesSelectionAsPrimaryAction property

bool get changesSelectionAsPrimaryAction

Indicates if the button changes selection as its primary action. This shows the menu as options for selection if a menu is populated and showsMenuAsPrimaryAction is enabled. If no menu is provided or it is not the primary action, UIControlStateSelected is toggled on and off for the primary action.

Implementation

bool get changesSelectionAsPrimaryAction {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIButton.changesSelectionAsPrimaryAction', iOS: (false, (15, 0, 0)));
  return _objc_msgSend_91o635(_$$ref.pointer, _sel_changesSelectionAsPrimaryAction);
}
set changesSelectionAsPrimaryAction (bool value)

Indicates if the button changes selection as its primary action. This shows the menu as options for selection if a menu is populated and showsMenuAsPrimaryAction is enabled. If no menu is provided or it is not the primary action, UIControlStateSelected is toggled on and off for the primary action.

Implementation

set changesSelectionAsPrimaryAction(bool value) {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIButton.setChangesSelectionAsPrimaryAction:', iOS: (false, (15, 0, 0)));
  _objc_msgSend_1s56lr9(_$$ref.pointer, _sel_setChangesSelectionAsPrimaryAction_, value);
}