configurationUpdateHandler property

ObjCBlock<Void Function(UIButton)>? get configurationUpdateHandler

Block-based equivalent to overriding -updateConfiguration in a subclass. Setting this handler will force the button into configuration-based behavior (see the configuration property). This block is called after -updateConfiguration

Implementation

objc.ObjCBlock<ffi.Void Function(UIButton)>? get configurationUpdateHandler {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIButton.configurationUpdateHandler', iOS: (false, (15, 0, 0)));
  final $ret = _objc_msgSend_uwvaik(_$$ref.pointer, _sel_configurationUpdateHandler);
  return $ret.address == 0 ? null : ObjCBlock_ffiVoid_UIButton.fromPointer($ret, retain: true, release: true);
}
set configurationUpdateHandler (ObjCBlock<Void Function(UIButton)>? value)

Block-based equivalent to overriding -updateConfiguration in a subclass. Setting this handler will force the button into configuration-based behavior (see the configuration property). This block is called after -updateConfiguration

Implementation

set configurationUpdateHandler(objc.ObjCBlock<ffi.Void Function(UIButton)>? value) {
  final _$$ref = object$.ref;
  final _$$ref$1 = value?.ref;
  objc.checkOsVersionInternal('UIButton.setConfigurationUpdateHandler:', iOS: (false, (15, 0, 0)));
  _objc_msgSend_f167m6(_$$ref.pointer, _sel_setConfigurationUpdateHandler_, _$$ref$1?.pointer ?? ffi.nullptr);
}