pointerStyleProvider property
! @abstract Called when the system pointer hovers over this button if its pointer interaction is enabled. The system calls this block with a proposed UIPointerEffect and UIPointerShape. You may use them to construct a customized version of the system provided style or return an entirely custom one. Setting this property automatically enables the button's pointer interaction and sets @c pointerInteractionEnabled to true.
Implementation
objc.ObjCBlock<UIPointerStyle? Function(UIButton, UIPointerEffect, UIPointerShape)>? get pointerStyleProvider {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.pointerStyleProvider', iOS: (false, (13, 4, 0)));
final $ret = _objc_msgSend_uwvaik(_$$ref.pointer, _sel_pointerStyleProvider);
return $ret.address == 0
? null
: ObjCBlock_UIPointerStyle_UIButton_UIPointerEffect_UIPointerShape.fromPointer(
$ret,
retain: true,
release: true,
);
}
! @abstract Called when the system pointer hovers over this button if its pointer interaction is enabled. The system calls this block with a proposed UIPointerEffect and UIPointerShape. You may use them to construct a customized version of the system provided style or return an entirely custom one. Setting this property automatically enables the button's pointer interaction and sets @c pointerInteractionEnabled to true.
Implementation
set pointerStyleProvider(objc.ObjCBlock<UIPointerStyle? Function(UIButton, UIPointerEffect, UIPointerShape)>? value) {
final _$$ref = object$.ref;
final _$$ref$1 = value?.ref;
objc.checkOsVersionInternal('UIButton.setPointerStyleProvider:', iOS: (false, (13, 4, 0)));
_objc_msgSend_f167m6(_$$ref.pointer, _sel_setPointerStyleProvider_, _$$ref$1?.pointer ?? ffi.nullptr);
}