reversesTitleShadowWhenHighlighted property
- @Deprecated('This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler')
reversesTitleShadowWhenHighlighted
Implementation
@Deprecated(
'This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler',
)
bool get reversesTitleShadowWhenHighlighted {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.reversesTitleShadowWhenHighlighted', iOS: (false, (2, 0, 0)));
return _objc_msgSend_91o635(_$$ref.pointer, _sel_reversesTitleShadowWhenHighlighted);
}
- @Deprecated('This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler')
setReversesTitleShadowWhenHighlighted:
Implementation
@Deprecated(
'This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler',
)
set reversesTitleShadowWhenHighlighted(bool value) {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.setReversesTitleShadowWhenHighlighted:', iOS: (false, (2, 0, 0)));
_objc_msgSend_1s56lr9(_$$ref.pointer, _sel_setReversesTitleShadowWhenHighlighted_, value);
}