setNeedsUpdateConfiguration method
void
setNeedsUpdateConfiguration()
Requests the view update its configuration for its current state. This method is called automatically when the button's state may have changed, as well as in other circumstances where an update may be required. Multiple requests may be coalesced into a single update at the appropriate time.
Implementation
void setNeedsUpdateConfiguration() {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.setNeedsUpdateConfiguration', iOS: (false, (15, 0, 0)));
_objc_msgSend_1pl9qdv(_$$ref.pointer, _sel_setNeedsUpdateConfiguration);
}