UIFocusEnvironment extension type
WARNING: UIFocusEnvironment is a stub. To generate bindings for this class, include UIFocusEnvironment in your config's objc-protocols list.
Objects conforming to UIFocusEnvironment influence and respond to focus behavior within a specific area of the screen that they control.
- on
-
- ObjCProtocol
- Implementers
Constructors
- UIFocusEnvironment.as(ObjCObject other)
-
Constructs a UIFocusEnvironment that points to the same underlying object as
other. -
UIFocusEnvironment.fromPointer(Pointer<
ObjCObjectImpl> other, {bool retain = false, bool release = false}) - Constructs a UIFocusEnvironment that wraps the given raw object pointer.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited