UIFocusItemContainer extension type
WARNING: UIFocusItemContainer is a stub. To generate bindings for this class, include UIFocusItemContainer in your config's objc-protocols list.
Objects conforming to UIFocusItemContainer are responsible for providing which focus items they contain and where they are.
- on
-
- ObjCProtocol
- Implementers
Constructors
- UIFocusItemContainer.as(ObjCObject other)
-
Constructs a UIFocusItemContainer that points to the same underlying object as
other. -
UIFocusItemContainer.fromPointer(Pointer<
ObjCObjectImpl> other, {bool retain = false, bool release = false}) - Constructs a UIFocusItemContainer that wraps the given raw object pointer.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited