UIMenuOptions class sealed

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

UIMenuOptionsDestructive → const int
Indicates whether the menu should be rendered with a destructive appearance in its parent
UIMenuOptionsDisplayInline → const int
Show children inline in parent, instead of hierarchically
UIMenuOptionsSingleSelection → const int
Indicates whether the menu (and any submenus) should only allow a single "on" menu item.