defersCurrentPageDisplay property

  1. @Deprecated('defersCurrentPageDisplay no longer does anything reasonable with the new interaction mode.')
bool get defersCurrentPageDisplay

if set, tapping to a new page won't update the currently displayed page until -updateCurrentPageDisplay is called. default is NO

Implementation

@Deprecated('defersCurrentPageDisplay no longer does anything reasonable with the new interaction mode.')
bool get defersCurrentPageDisplay {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIPageControl.defersCurrentPageDisplay', iOS: (false, (2, 0, 0)));
  return _objc_msgSend_91o635(_$$ref.pointer, _sel_defersCurrentPageDisplay);
}
  1. @Deprecated('defersCurrentPageDisplay no longer does anything reasonable with the new interaction mode.')
set defersCurrentPageDisplay (bool value)

if set, tapping to a new page won't update the currently displayed page until -updateCurrentPageDisplay is called. default is NO

Implementation

@Deprecated('defersCurrentPageDisplay no longer does anything reasonable with the new interaction mode.')
set defersCurrentPageDisplay(bool value) {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIPageControl.setDefersCurrentPageDisplay:', iOS: (false, (2, 0, 0)));
  _objc_msgSend_1s56lr9(_$$ref.pointer, _sel_setDefersCurrentPageDisplay_, value);
}