UIPageControlBackgroundStyle enum
Values
- UIPageControlBackgroundStyleAutomatic → const UIPageControlBackgroundStyle
-
The default background style that adapts based on the current interaction state.
const UIPageControlBackgroundStyle(0) - UIPageControlBackgroundStyleProminent → const UIPageControlBackgroundStyle
-
The background style that shows a full background regardless of the interaction
const UIPageControlBackgroundStyle(1) - UIPageControlBackgroundStyleMinimal → const UIPageControlBackgroundStyle
-
The background style that shows a minimal background regardless of the interaction
const UIPageControlBackgroundStyle(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → UIPageControlBackgroundStyle
Constants
-
values
→ const List<
UIPageControlBackgroundStyle> - A constant List of the values in this enum, in order of their declaration.