UIScreen extension type
UIScreen
- on
-
- ObjCObject
- Available extensions
Constructors
- UIScreen.as(ObjCObject other)
-
Constructs a UIScreen that points to the same underlying object as
other. -
UIScreen.fromPointer(Pointer<
ObjCObjectImpl> other, {bool retain = false, bool release = false}) - Constructs a UIScreen that wraps the given raw object pointer.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited