initWithFrame$1 method

UISlider initWithFrame$1(
  1. CGRect frame, {
  2. UIAction? primaryAction,
})

Initializes the control and adds primaryAction for the UIControlEventPrimaryActionTriggered control event. Subclasses of UIControl may alter or add behaviors around the usage of primaryAction, see subclass documentation of this initializer for additional information.

Implementation

UISlider initWithFrame$1(objc.CGRect frame, {UIAction? primaryAction}) {
  final _$$ref$6 = object$.ref;
  final _$$ref$7 = primaryAction?.ref;
  objc.checkOsVersionInternal('UISlider.initWithFrame:primaryAction:', iOS: (false, (14, 0, 0)));
  final $ret = _objc_msgSend_gxusyk(
    _$$ref$6.retainAndReturnPointer(),
    _sel_initWithFrame_primaryAction_,
    frame,
    _$$ref$7?.pointer ?? ffi.nullptr,
  );
  return UISlider.fromPointer($ret, retain: false, release: true);
}