UIStackViewDistribution enum

Inheritance
Available extensions

Values

UIStackViewDistributionFill → const UIStackViewDistribution
const UIStackViewDistribution(0)
UIStackViewDistributionFillEqually → const UIStackViewDistribution
const UIStackViewDistribution(1)
UIStackViewDistributionFillProportionally → const UIStackViewDistribution
const UIStackViewDistribution(2)
UIStackViewDistributionEqualSpacing → const UIStackViewDistribution
const UIStackViewDistribution(3)
UIStackViewDistributionEqualCentering → const UIStackViewDistribution
const UIStackViewDistribution(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) UIStackViewDistribution

Constants

values → const List<UIStackViewDistribution>
A constant List of the values in this enum, in order of their declaration.