UIStateRestoring extension type
WARNING: UIStateRestoring is a stub. To generate bindings for this class, include UIStateRestoring in your config's objc-protocols list.
UIStateRestoring
- on
-
- ObjCProtocol
Constructors
- UIStateRestoring.as(ObjCObject other)
-
Constructs a UIStateRestoring that points to the same underlying object as
other. -
UIStateRestoring.fromPointer(Pointer<
ObjCObjectImpl> other, {bool retain = false, bool release = false}) - Constructs a UIStateRestoring that wraps the given raw object pointer.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited