UITabBarSystemItem enum

Inheritance
Available extensions

Values

UITabBarSystemItemMore → const UITabBarSystemItem
const UITabBarSystemItem(0)
UITabBarSystemItemFavorites → const UITabBarSystemItem
const UITabBarSystemItem(1)
UITabBarSystemItemFeatured → const UITabBarSystemItem
const UITabBarSystemItem(2)
UITabBarSystemItemTopRated → const UITabBarSystemItem
const UITabBarSystemItem(3)
UITabBarSystemItemRecents → const UITabBarSystemItem
const UITabBarSystemItem(4)
UITabBarSystemItemContacts → const UITabBarSystemItem
const UITabBarSystemItem(5)
UITabBarSystemItemHistory → const UITabBarSystemItem
const UITabBarSystemItem(6)
UITabBarSystemItemBookmarks → const UITabBarSystemItem
const UITabBarSystemItem(7)
UITabBarSystemItemSearch → const UITabBarSystemItem
const UITabBarSystemItem(8)
UITabBarSystemItemDownloads → const UITabBarSystemItem
const UITabBarSystemItem(9)
UITabBarSystemItemMostRecent → const UITabBarSystemItem
const UITabBarSystemItem(10)
UITabBarSystemItemMostViewed → const UITabBarSystemItem
const UITabBarSystemItem(11)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) UITabBarSystemItem

Constants

values → const List<UITabBarSystemItem>
A constant List of the values in this enum, in order of their declaration.