UITextField$Methods extension

on

Properties

adjustsFontForContentSizeCategory bool

Available on UITextField, provided by the UITextField$Methods extension

adjustsFontForContentSizeCategory
getter/setter pair
adjustsFontSizeToFitWidth bool

Available on UITextField, provided by the UITextField$Methods extension

adjustsFontSizeToFitWidth
getter/setter pair
allowsEditingTextAttributes bool

Available on UITextField, provided by the UITextField$Methods extension

allowsEditingTextAttributes
getter/setter pair
attributedPlaceholder ↔ NSAttributedString?

Available on UITextField, provided by the UITextField$Methods extension

attributedPlaceholder
getter/setter pair
attributedText ↔ NSAttributedString?

Available on UITextField, provided by the UITextField$Methods extension

attributedText
getter/setter pair
autocapitalizationType UITextAutocapitalizationType

Available on UITextField, provided by the UITextField$Methods extension

autocapitalizationType
getter/setter pair
autocorrectionType UITextAutocorrectionType

Available on UITextField, provided by the UITextField$Methods extension

autocorrectionType
getter/setter pair
background UIImage?

Available on UITextField, provided by the UITextField$Methods extension

background
getter/setter pair
beginningOfDocument UITextPosition

Available on UITextField, provided by the UITextField$Methods extension

beginningOfDocument
no setter
borderStyle UITextBorderStyle

Available on UITextField, provided by the UITextField$Methods extension

borderStyle
getter/setter pair
clearButtonMode UITextFieldViewMode

Available on UITextField, provided by the UITextField$Methods extension

clearButtonMode
getter/setter pair
clearsOnBeginEditing bool

Available on UITextField, provided by the UITextField$Methods extension

clearsOnBeginEditing
getter/setter pair
clearsOnInsertion bool

Available on UITextField, provided by the UITextField$Methods extension

clearsOnInsertion
getter/setter pair
defaultTextAttributes ↔ NSDictionary

Available on UITextField, provided by the UITextField$Methods extension

defaultTextAttributes
getter/setter pair
delegate UITextFieldDelegate?

Available on UITextField, provided by the UITextField$Methods extension

delegate
getter/setter pair
disabledBackground UIImage?

Available on UITextField, provided by the UITextField$Methods extension

disabledBackground
getter/setter pair
enablesReturnKeyAutomatically bool

Available on UITextField, provided by the UITextField$Methods extension

enablesReturnKeyAutomatically
getter/setter pair
endOfDocument UITextPosition

Available on UITextField, provided by the UITextField$Methods extension

endOfDocument
no setter
font UIFont?

Available on UITextField, provided by the UITextField$Methods extension

font
getter/setter pair
hasText bool

Available on UITextField, provided by the UITextField$Methods extension

hasText
no setter
inputAccessoryView UIView?

Available on UITextField, provided by the UITextField$Methods extension

inputAccessoryView
getter/setter pair
inputDelegate UITextInputDelegate?

Available on UITextField, provided by the UITextField$Methods extension

inputDelegate
getter/setter pair
inputView UIView?

Available on UITextField, provided by the UITextField$Methods extension

inputView
getter/setter pair
insertDictationResultPlaceholder → ObjCObject

Available on UITextField, provided by the UITextField$Methods extension

insertDictationResultPlaceholder
no setter
isEditing bool

Available on UITextField, provided by the UITextField$Methods extension

isEditing
no setter
isSecureTextEntry bool

Available on UITextField, provided by the UITextField$Methods extension

isSecureTextEntry
getter/setter pair
keyboardAppearance UIKeyboardAppearance

Available on UITextField, provided by the UITextField$Methods extension

keyboardAppearance
getter/setter pair
keyboardType UIKeyboardType

Available on UITextField, provided by the UITextField$Methods extension

keyboardType
getter/setter pair
leftView UIView?

Available on UITextField, provided by the UITextField$Methods extension

leftView
getter/setter pair
leftViewMode UITextFieldViewMode

Available on UITextField, provided by the UITextField$Methods extension

leftViewMode
getter/setter pair
markedTextRange UITextRange?

Available on UITextField, provided by the UITextField$Methods extension

markedTextRange
no setter
markedTextStyle ↔ NSDictionary?

Available on UITextField, provided by the UITextField$Methods extension

markedTextStyle
getter/setter pair
minimumFontSize double

Available on UITextField, provided by the UITextField$Methods extension

minimumFontSize
getter/setter pair
passwordRules UITextInputPasswordRules?

Available on UITextField, provided by the UITextField$Methods extension

passwordRules
getter/setter pair
placeholder ↔ NSString?

Available on UITextField, provided by the UITextField$Methods extension

placeholder
getter/setter pair
returnKeyType UIReturnKeyType

Available on UITextField, provided by the UITextField$Methods extension

returnKeyType
getter/setter pair
rightView UIView?

Available on UITextField, provided by the UITextField$Methods extension

rightView
getter/setter pair
rightViewMode UITextFieldViewMode

Available on UITextField, provided by the UITextField$Methods extension

rightViewMode
getter/setter pair
selectedTextRange UITextRange?

Available on UITextField, provided by the UITextField$Methods extension

selectedTextRange
getter/setter pair
selectionAffinity UITextStorageDirection

Available on UITextField, provided by the UITextField$Methods extension

selectionAffinity
getter/setter pair
smartDashesType UITextSmartDashesType

Available on UITextField, provided by the UITextField$Methods extension

smartDashesType
getter/setter pair
smartInsertDeleteType UITextSmartInsertDeleteType

Available on UITextField, provided by the UITextField$Methods extension

smartInsertDeleteType
getter/setter pair
smartQuotesType UITextSmartQuotesType

Available on UITextField, provided by the UITextField$Methods extension

smartQuotesType
getter/setter pair
spellCheckingType UITextSpellCheckingType

Available on UITextField, provided by the UITextField$Methods extension

spellCheckingType
getter/setter pair
text ↔ NSString?

Available on UITextField, provided by the UITextField$Methods extension

text
getter/setter pair
textAlignment NSTextAlignment

Available on UITextField, provided by the UITextField$Methods extension

textAlignment
getter/setter pair
textColor UIColor?

Available on UITextField, provided by the UITextField$Methods extension

textColor
getter/setter pair
textContentType ↔ NSString

Available on UITextField, provided by the UITextField$Methods extension

textContentType
getter/setter pair
textInputView UIView

Available on UITextField, provided by the UITextField$Methods extension

textInputView
no setter
tokenizer UITextInputTokenizer

Available on UITextField, provided by the UITextField$Methods extension

tokenizer
no setter
typingAttributes ↔ NSDictionary?

Available on UITextField, provided by the UITextField$Methods extension

typingAttributes
getter/setter pair

Methods

baseWritingDirectionForPosition(UITextPosition position, {required UITextStorageDirection inDirection}) NSWritingDirection

Available on UITextField, provided by the UITextField$Methods extension

baseWritingDirectionForPosition:inDirection:
beginFloatingCursorAtPoint(CGPoint point) → void

Available on UITextField, provided by the UITextField$Methods extension

beginFloatingCursorAtPoint:
borderRectForBounds(CGRect bounds) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

borderRectForBounds:
caretRectForPosition(UITextPosition position) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

caretRectForPosition:
characterOffsetOfPosition(UITextPosition position, {required UITextRange withinRange}) int

Available on UITextField, provided by the UITextField$Methods extension

characterOffsetOfPosition:withinRange:
characterRangeAtPoint(CGPoint point) UITextRange?

Available on UITextField, provided by the UITextField$Methods extension

characterRangeAtPoint:
characterRangeByExtendingPosition(UITextPosition position, {required UITextLayoutDirection inDirection}) UITextRange?

Available on UITextField, provided by the UITextField$Methods extension

characterRangeByExtendingPosition:inDirection:
clearButtonRectForBounds(CGRect bounds) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

clearButtonRectForBounds:
closestPositionToPoint(CGPoint point) UITextPosition?

Available on UITextField, provided by the UITextField$Methods extension

closestPositionToPoint:
closestPositionToPoint$1(CGPoint point, {required UITextRange withinRange}) UITextPosition?

Available on UITextField, provided by the UITextField$Methods extension

closestPositionToPoint:withinRange:
comparePosition(UITextPosition position, {required UITextPosition toPosition}) → NSComparisonResult

Available on UITextField, provided by the UITextField$Methods extension

comparePosition:toPosition:
deleteBackward() → void

Available on UITextField, provided by the UITextField$Methods extension

deleteBackward
dictationRecognitionFailed() → void

Available on UITextField, provided by the UITextField$Methods extension

dictationRecognitionFailed
dictationRecordingDidEnd() → void

Available on UITextField, provided by the UITextField$Methods extension

dictationRecordingDidEnd
drawPlaceholderInRect(CGRect rect) → void

Available on UITextField, provided by the UITextField$Methods extension

drawPlaceholderInRect:
drawTextInRect(CGRect rect) → void

Available on UITextField, provided by the UITextField$Methods extension

drawTextInRect:
editingRectForBounds(CGRect bounds) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

editingRectForBounds:
encodeWithCoder(NSCoder coder) → void

Available on UITextField, provided by the UITextField$Methods extension

encodeWithCoder:
endFloatingCursor() → void

Available on UITextField, provided by the UITextField$Methods extension

endFloatingCursor
firstRectForRange(UITextRange range) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

firstRectForRange:
frameForDictationResultPlaceholder(ObjCObject placeholder) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

frameForDictationResultPlaceholder:
init() UITextField

Available on UITextField, provided by the UITextField$Methods extension

init
initWithCoder(NSCoder coder) UITextField?

Available on UITextField, provided by the UITextField$Methods extension

initWithCoder:
initWithFrame(CGRect frame) UITextField

Available on UITextField, provided by the UITextField$Methods extension

initWithFrame:
initWithFrame$1(CGRect frame, {UIAction? primaryAction}) UITextField

Available on UITextField, provided by the UITextField$Methods extension

Initializes the control and adds primaryAction for the UIControlEventPrimaryActionTriggered control event. Subclasses of UIControl may alter or add behaviors around the usage of primaryAction, see subclass documentation of this initializer for additional information.
insertDictationResult(NSArray dictationResult) → void

Available on UITextField, provided by the UITextField$Methods extension

insertDictationResult:
insertText(NSString text) → void

Available on UITextField, provided by the UITextField$Methods extension

insertText:
insertText$1(NSString text, {required NSArray alternatives, required UITextAlternativeStyle style}) → void

Available on UITextField, provided by the UITextField$Methods extension

insertText:alternatives:style:
insertTextPlaceholderWithSize(CGSize size) UITextPlaceholder

Available on UITextField, provided by the UITextField$Methods extension

insertTextPlaceholderWithSize:
leftViewRectForBounds(CGRect bounds) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

leftViewRectForBounds:
offsetFromPosition(UITextPosition from, {required UITextPosition toPosition}) int

Available on UITextField, provided by the UITextField$Methods extension

offsetFromPosition:toPosition:
placeholderRectForBounds(CGRect bounds) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

placeholderRectForBounds:
positionFromPosition(UITextPosition position, {required UITextLayoutDirection inDirection, required int offset}) UITextPosition?

Available on UITextField, provided by the UITextField$Methods extension

positionFromPosition:inDirection:offset:
positionFromPosition$1(UITextPosition position, {required int offset}) UITextPosition?

Available on UITextField, provided by the UITextField$Methods extension

positionFromPosition:offset:
positionWithinRange(UITextRange range, {required int atCharacterOffset}) UITextPosition?

Available on UITextField, provided by the UITextField$Methods extension

positionWithinRange:atCharacterOffset:
positionWithinRange$1(UITextRange range, {required UITextLayoutDirection farthestInDirection}) UITextPosition?

Available on UITextField, provided by the UITextField$Methods extension

positionWithinRange:farthestInDirection:
removeDictationResultPlaceholder(ObjCObject placeholder, {required bool willInsertResult}) → void

Available on UITextField, provided by the UITextField$Methods extension

removeDictationResultPlaceholder:willInsertResult:
removeTextPlaceholder(UITextPlaceholder textPlaceholder) → void

Available on UITextField, provided by the UITextField$Methods extension

removeTextPlaceholder:
replaceRange(UITextRange range, {required NSString withText}) → void

Available on UITextField, provided by the UITextField$Methods extension

replaceRange:withText:
rightViewRectForBounds(CGRect bounds) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

rightViewRectForBounds:
selectionRectsForRange(UITextRange range) → NSArray

Available on UITextField, provided by the UITextField$Methods extension

selectionRectsForRange:
setAttributedMarkedText(NSAttributedString? markedText, {required NSRange selectedRange}) → void

Available on UITextField, provided by the UITextField$Methods extension

setAttributedMarkedText:selectedRange:
setBaseWritingDirection(NSWritingDirection writingDirection, {required UITextRange forRange}) → void

Available on UITextField, provided by the UITextField$Methods extension

setBaseWritingDirection:forRange:
setMarkedText(NSString? markedText, {required NSRange selectedRange}) → void

Available on UITextField, provided by the UITextField$Methods extension

setMarkedText:selectedRange:
shouldChangeTextInRange(UITextRange range, {required NSString replacementText}) bool

Available on UITextField, provided by the UITextField$Methods extension

shouldChangeTextInRange:replacementText:
textInRange(UITextRange range) → NSString?

Available on UITextField, provided by the UITextField$Methods extension

textInRange:
textRangeFromPosition(UITextPosition fromPosition, {required UITextPosition toPosition}) UITextRange?

Available on UITextField, provided by the UITextField$Methods extension

textRangeFromPosition:toPosition:
textRectForBounds(CGRect bounds) → CGRect

Available on UITextField, provided by the UITextField$Methods extension

textRectForBounds:
textStylingAtPosition(UITextPosition position, {required UITextStorageDirection inDirection}) → NSDictionary?

Available on UITextField, provided by the UITextField$Methods extension

textStylingAtPosition:inDirection:
unmarkText() → void

Available on UITextField, provided by the UITextField$Methods extension

unmarkText
updateFloatingCursorAtPoint(CGPoint point) → void

Available on UITextField, provided by the UITextField$Methods extension

updateFloatingCursorAtPoint: