UITitlebar extension type

UITitlebar

on
  • ObjCObject
Available extensions

Constructors

UITitlebar()
Returns a new instance of UITitlebar constructed with the default new method.
UITitlebar.as(ObjCObject other)
Constructs a UITitlebar that points to the same underlying object as other.
UITitlebar.fromPointer(Pointer<ObjCObjectImpl> other, {bool retain = false, bool release = false})
Constructs a UITitlebar that wraps the given raw object pointer.

Properties

autoHidesToolbarInFullScreen bool

Available on UITitlebar, provided by the UITitlebar$Methods extension

autoHidesToolbarInFullScreen
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
object$ → ObjCObject
final
ref → ObjCObjectRef
finalinherited
representedURL ↔ NSURL?

Available on UITitlebar, provided by the UITitlebar$Methods extension

representedURL
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separatorStyle UITitlebarSeparatorStyle

Available on UITitlebar, provided by the UITitlebar$Methods extension

separatorStyle
getter/setter pair
titleVisibility UITitlebarTitleVisibility

Available on UITitlebar, provided by the UITitlebar$Methods extension

titleVisibility
getter/setter pair
toolbar NSToolbar?

Available on UITitlebar, provided by the UITitlebar$Methods extension

toolbar
getter/setter pair
toolbarStyle UITitlebarToolbarStyle

Available on UITitlebar, provided by the UITitlebar$Methods extension

toolbarStyle
getter/setter pair

Methods

init() UITitlebar

Available on UITitlebar, provided by the UITitlebar$Methods extension

init
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

alloc() UITitlebar
alloc
allocWithZone(Pointer<NSZone> zone) UITitlebar
allocWithZone:
isA(ObjCObject obj) bool
Returns whether obj is an instance of UITitlebar.
new$() UITitlebar
new