UIToolbar$Methods extension

on

Properties

barPosition UIBarPosition

Available on UIToolbar, provided by the UIToolbar$Methods extension

barPosition
no setter
barStyle UIBarStyle

Available on UIToolbar, provided by the UIToolbar$Methods extension

barStyle
getter/setter pair
barTintColor UIColor?

Available on UIToolbar, provided by the UIToolbar$Methods extension

barTintColor
getter/setter pair
compactAppearance UIToolbarAppearance?

Available on UIToolbar, provided by the UIToolbar$Methods extension

Describes the appearance attributes for the toolbar to use when it is displayed with its compact height. If not set, the standardAppearance will be used instead.
getter/setter pair
compactScrollEdgeAppearance UIToolbarAppearance?

Available on UIToolbar, provided by the UIToolbar$Methods extension

Describes the appearance attributes for the toolbar to use at compact height when an observable scroll view is scrolled to the bottom. If not set, will fall back to scrollEdgeAppearance followed by compactAppearance and finally standardAppearance.
getter/setter pair
delegate UIToolbarDelegate?

Available on UIToolbar, provided by the UIToolbar$Methods extension

delegate
getter/setter pair
isTranslucent bool

Available on UIToolbar, provided by the UIToolbar$Methods extension

isTranslucent
getter/setter pair
items ↔ NSArray?

Available on UIToolbar, provided by the UIToolbar$Methods extension

items
getter/setter pair
scrollEdgeAppearance UIToolbarAppearance?

Available on UIToolbar, provided by the UIToolbar$Methods extension

Describes the appearance attributes for the toolbar to use at standard height when an observable scroll view is scrolled to the bottom. If not set, standardAppearance will be used instead.
getter/setter pair
standardAppearance UIToolbarAppearance

Available on UIToolbar, provided by the UIToolbar$Methods extension

Describes the appearance attributes for the toolbar to use when it is displayed with its standard height.
getter/setter pair
tintColor UIColor

Available on UIToolbar, provided by the UIToolbar$Methods extension

tintColor
getter/setter pair

Methods

backgroundImageForToolbarPosition(UIBarPosition topOrBottom, {required UIBarMetrics barMetrics}) UIImage?

Available on UIToolbar, provided by the UIToolbar$Methods extension

backgroundImageForToolbarPosition:barMetrics:
init() UIToolbar

Available on UIToolbar, provided by the UIToolbar$Methods extension

init
initWithCoder(NSCoder coder) UIToolbar?

Available on UIToolbar, provided by the UIToolbar$Methods extension

initWithCoder:
initWithFrame(CGRect frame) UIToolbar

Available on UIToolbar, provided by the UIToolbar$Methods extension

initWithFrame:
setBackgroundImage(UIImage? backgroundImage, {required UIBarPosition forToolbarPosition, required UIBarMetrics barMetrics}) → void

Available on UIToolbar, provided by the UIToolbar$Methods extension

setBackgroundImage:forToolbarPosition:barMetrics:
setItems(NSArray? items, {required bool animated}) → void

Available on UIToolbar, provided by the UIToolbar$Methods extension

setItems:animated:
setShadowImage(UIImage? shadowImage, {required UIBarPosition forToolbarPosition}) → void

Available on UIToolbar, provided by the UIToolbar$Methods extension

setShadowImage:forToolbarPosition:
shadowImageForToolbarPosition(UIBarPosition topOrBottom) UIImage?

Available on UIToolbar, provided by the UIToolbar$Methods extension

shadowImageForToolbarPosition: