scrollEdgeAppearance property

UIToolbarAppearance? get scrollEdgeAppearance

Describes the appearance attributes for the toolbar to use at standard height when an observable scroll view is scrolled to the bottom. If not set, standardAppearance will be used instead.

Implementation

UIToolbarAppearance? get scrollEdgeAppearance {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIToolbar.scrollEdgeAppearance', iOS: (false, (15, 0, 0)));
  final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_scrollEdgeAppearance);
  return $ret.address == 0 ? null : UIToolbarAppearance.fromPointer($ret, retain: true, release: true);
}
set scrollEdgeAppearance (UIToolbarAppearance? value)

Describes the appearance attributes for the toolbar to use at standard height when an observable scroll view is scrolled to the bottom. If not set, standardAppearance will be used instead.

Implementation

set scrollEdgeAppearance(UIToolbarAppearance? value) {
  final _$$ref = object$.ref;
  final _$$ref$1 = value?.ref;
  objc.checkOsVersionInternal('UIToolbar.setScrollEdgeAppearance:', iOS: (false, (15, 0, 0)));
  _objc_msgSend_xtuoz7(_$$ref.pointer, _sel_setScrollEdgeAppearance_, _$$ref$1?.pointer ?? ffi.nullptr);
}