rotatingHeaderView method
- @Deprecated('Header views are animated along with the rest of the view hierarchy')
rotatingHeaderView
Implementation
@Deprecated('Header views are animated along with the rest of the view hierarchy')
UIView? rotatingHeaderView() {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIViewController.rotatingHeaderView', iOS: (false, (2, 0, 0)));
final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_rotatingHeaderView);
return $ret.address == 0 ? null : UIView.fromPointer($ret, retain: true, release: true);
}