uikit_extensions library

Extensions

UIKitColorExtension on Color

Functions

createCGRect(double x, double y, double width, double height) → CGRect
Helper to create CGRect.
createCGSize(double width, double height) → CGSize
getKeyWindow([UIWindowScene? scene]) UIWindow?
Returns the key window for scene, or a best-effort key window from the most relevant foreground window scene when scene is omitted.