ObjCBlock_ffiVoid_UIAction_objcObjCObjectImpl_objcObjCSelector_UIControlEvents_bool class abstract final
Construction methods for objc.ObjCBlock<ffi.Void Function(UIAction?, ffi.Pointer<objc.ObjCObjectImpl>?, ffi.Pointer<objc.ObjCSelector>, ffi.UnsignedLong, ffi.Pointer<ffi.Bool>)>.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
blocking(
void fn(UIAction?, ObjCObject?, Pointer< ObjCSelector> , int, Pointer<Bool> ), {bool keepIsolateAlive = true}) → ObjCBlock<Void Function(UIAction?, Pointer< ObjCObjectImpl> ?, Pointer<ObjCSelector> , UnsignedLong, Pointer<Bool> )> - Creates a blocking block from a Dart function.
-
fromFunction(
void fn(UIAction?, ObjCObject?, Pointer< ObjCSelector> , int, Pointer<Bool> ), {bool keepIsolateAlive = true}) → ObjCBlock<Void Function(UIAction?, Pointer< ObjCObjectImpl> ?, Pointer<ObjCSelector> , UnsignedLong, Pointer<Bool> )> - Creates a block from a Dart function.
-
fromFunctionPointer(
Pointer< NativeFunction< ptr) → ObjCBlock<Void Function(Pointer< >ObjCObjectImpl> arg0, Pointer<ObjCObjectImpl> arg1, Pointer<ObjCSelector> arg2, UnsignedLong arg3, Pointer<Bool> arg4)>Void Function(UIAction?, Pointer< ObjCObjectImpl> ?, Pointer<ObjCSelector> , UnsignedLong, Pointer<Bool> )> - Creates a block from a C function pointer.
-
fromPointer(
Pointer< ObjCBlockImpl> pointer, {bool retain = false, bool release = false}) → ObjCBlock<Void Function(UIAction?, Pointer< ObjCObjectImpl> ?, Pointer<ObjCSelector> , UnsignedLong, Pointer<Bool> )> - Returns a block that wraps the given raw block pointer.
-
listener(
void fn(UIAction?, ObjCObject?, Pointer< ObjCSelector> , int, Pointer<Bool> ), {bool keepIsolateAlive = true}) → ObjCBlock<Void Function(UIAction?, Pointer< ObjCObjectImpl> ?, Pointer<ObjCSelector> , UnsignedLong, Pointer<Bool> )> - Creates a listener block from a Dart function.