UIActivityIndicatorViewStyle enum
Values
- UIActivityIndicatorViewStyleMedium → const UIActivityIndicatorViewStyle
-
const UIActivityIndicatorViewStyle(100) - UIActivityIndicatorViewStyleLarge → const UIActivityIndicatorViewStyle
-
const UIActivityIndicatorViewStyle(101) - UIActivityIndicatorViewStyleWhiteLarge → const UIActivityIndicatorViewStyle
-
const UIActivityIndicatorViewStyle(0) - UIActivityIndicatorViewStyleWhite → const UIActivityIndicatorViewStyle
-
const UIActivityIndicatorViewStyle(1) - UIActivityIndicatorViewStyleGray → const UIActivityIndicatorViewStyle
-
const UIActivityIndicatorViewStyle(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → UIActivityIndicatorViewStyle
Constants
-
values
→ const List<
UIActivityIndicatorViewStyle> - A constant List of the values in this enum, in order of their declaration.