shadowColor property
A color to use for the shadow. Its specific behavior depends on the value of shadowImage. If shadowImage is nil, then the shadowColor is used to color the bar's default shadow; a nil or clearColor shadowColor will result in no shadow. If shadowImage is a template image, then the shadowColor is used to tint the image; a nil or clearColor shadowColor will also result in no shadow. If the shadowImage is not a template image, then it will be rendered regardless of the value of shadowColor.
Implementation
UIColor? get shadowColor {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIBarAppearance.shadowColor', iOS: (false, (13, 0, 0)));
final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_shadowColor);
return $ret.address == 0 ? null : UIColor.fromPointer($ret, retain: true, release: true);
}
A color to use for the shadow. Its specific behavior depends on the value of shadowImage. If shadowImage is nil, then the shadowColor is used to color the bar's default shadow; a nil or clearColor shadowColor will result in no shadow. If shadowImage is a template image, then the shadowColor is used to tint the image; a nil or clearColor shadowColor will also result in no shadow. If the shadowImage is not a template image, then it will be rendered regardless of the value of shadowColor.
Implementation
set shadowColor(UIColor? value) {
final _$$ref = object$.ref;
final _$$ref$1 = value?.ref;
objc.checkOsVersionInternal('UIBarAppearance.setShadowColor:', iOS: (false, (13, 0, 0)));
_objc_msgSend_xtuoz7(_$$ref.pointer, _sel_setShadowColor_, _$$ref$1?.pointer ?? ffi.nullptr);
}