adjustsImageWhenHighlighted property
- @Deprecated('This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler')
adjustsImageWhenHighlighted
Implementation
@Deprecated(
'This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler',
)
bool get adjustsImageWhenHighlighted {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.adjustsImageWhenHighlighted', iOS: (false, (2, 0, 0)));
return _objc_msgSend_91o635(_$$ref.pointer, _sel_adjustsImageWhenHighlighted);
}
- @Deprecated('This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler')
setAdjustsImageWhenHighlighted:
Implementation
@Deprecated(
'This property is ignored when using UIButtonConfiguration, you may customize to replicate this behavior via a configurationUpdateHandler',
)
set adjustsImageWhenHighlighted(bool value) {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.setAdjustsImageWhenHighlighted:', iOS: (false, (2, 0, 0)));
_objc_msgSend_1s56lr9(_$$ref.pointer, _sel_setAdjustsImageWhenHighlighted_, value);
}