imageRectForContentRect method

  1. @Deprecated('Override layoutSubviews, call super, and position views as you desire.')
CGRect imageRectForContentRect(
  1. CGRect contentRect
)

imageRectForContentRect:

Implementation

@Deprecated('Override layoutSubviews, call super, and position views as you desire.')
objc.CGRect imageRectForContentRect(objc.CGRect contentRect) {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIButton.imageRectForContentRect:', iOS: (false, (2, 0, 0)));
  final $ptr = pkg_ffi.calloc<objc.CGRect>();
  objc.useMsgSendVariants
      ? _objc_msgSend_1gn1s3dStret($ptr, _$$ref.pointer, _sel_imageRectForContentRect_, contentRect)
      : $ptr.ref = _objc_msgSend_1gn1s3d(_$$ref.pointer, _sel_imageRectForContentRect_, contentRect);
  final $finalizable = $ptr.cast<ffi.Uint8>().asTypedList(
    ffi.sizeOf<objc.CGRect>(),
    finalizer: pkg_ffi.calloc.nativeFree,
  );
  return ffi.Struct.create<objc.CGRect>($finalizable);
}