menu property
UIMenu?
get
menu
An optional menu for the button to display. The button will automatically enable or disable its contextMenuInteraction when a non-nil or nil menu is set. Defaults to nil.
Implementation
UIMenu? get menu {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.menu', iOS: (false, (14, 0, 0)));
final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_menu);
return $ret.address == 0 ? null : UIMenu.fromPointer($ret, retain: true, release: true);
}
set
menu
()
An optional menu for the button to display. The button will automatically enable or disable its contextMenuInteraction when a non-nil or nil menu is set. Defaults to nil.
Implementation
set menu(UIMenu? value) {
final _$$ref = object$.ref;
final _$$ref$1 = value?.ref;
objc.checkOsVersionInternal('UIButton.setMenu:', iOS: (false, (14, 0, 0)));
_objc_msgSend_xtuoz7(_$$ref.pointer, _sel_setMenu_, _$$ref$1?.pointer ?? ffi.nullptr);
}