updateConfiguration method
void
updateConfiguration()
Subclasses should override this method and update the button's configuration. This method should not be called directly, use setNeedsUpdateConfiguration to request an update.
Implementation
void updateConfiguration() {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIButton.updateConfiguration', iOS: (false, (15, 0, 0)));
_objc_msgSend_1pl9qdv(_$$ref.pointer, _sel_updateConfiguration);
}