UIPageControl$Methods extension
Properties
- allowsContinuousInteraction ↔ bool
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
Returns YES if the continuous interaction is enabled, NO otherwise. Default is YES.getter/setter pair - backgroundStyle ↔ UIPageControlBackgroundStyle
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
The preferred background style. Default is UIPageControlBackgroundStyleAutomatic on iOS, and UIPageControlBackgroundStyleProminent on tvOS.getter/setter pair - currentPage ↔ int
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
default is 0. Value is pinned to 0..numberOfPages-1getter/setter pair - currentPageIndicatorTintColor ↔ UIColor?
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
The tint color for the currently-selected indicators. Default is nil.getter/setter pair - defersCurrentPageDisplay ↔ bool
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
if set, tapping to a new page won't update the currently displayed page until -updateCurrentPageDisplay is called. default is NOgetter/setter pair - hidesForSinglePage ↔ bool
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
hides the indicator if there is only one page, default is NOgetter/setter pair - interactionState → UIPageControlInteractionState
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
The current interaction state for when the current page changes. Default is UIPageControlInteractionStateNoneno setter - numberOfPages ↔ int
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
default is 0getter/setter pair - pageIndicatorTintColor ↔ UIColor?
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
The tint color for non-selected indicators. Default is nil.getter/setter pair - preferredIndicatorImage ↔ UIImage?
-
Available on UIPageControl, provided by the UIPageControl$Methods extension
The preferred image for indicators. Symbol images are recommended. Default is nil.getter/setter pair
Methods
-
indicatorImageForPage(
int page) → UIImage? -
Available on UIPageControl, provided by the UIPageControl$Methods extension
! @abstract Returns the override indicator image for the specific page, nil if no override image was set. @param page Must be in the range of 0..numberOfPages -
init(
) → UIPageControl -
Available on UIPageControl, provided by the UIPageControl$Methods extension
init -
initWithCoder(
NSCoder coder) → UIPageControl? -
Available on UIPageControl, provided by the UIPageControl$Methods extension
initWithCoder: -
initWithFrame(
CGRect frame) → UIPageControl -
Available on UIPageControl, provided by the UIPageControl$Methods extension
initWithFrame: -
initWithFrame$1(
CGRect frame, {UIAction? primaryAction}) → UIPageControl -
Available on UIPageControl, provided by the UIPageControl$Methods extension
Initializes the control and adds primaryAction for the UIControlEventPrimaryActionTriggered control event. Subclasses of UIControl may alter or add behaviors around the usage of primaryAction, see subclass documentation of this initializer for additional information. -
setIndicatorImage(
UIImage? image, {required int forPage}) → void -
Available on UIPageControl, provided by the UIPageControl$Methods extension
! @abstract Override the indicator image for a specific page. Symbol images are recommended. @param image The image for the indicator. Resets to the default if image is nil. @param page Must be in the range of 0..numberOfPages -
sizeForNumberOfPages(
int pageCount) → CGSize -
Available on UIPageControl, provided by the UIPageControl$Methods extension
Returns the minimum size required to display indicators for the given page count. Can be used to size the control if the page count could change. -
updateCurrentPageDisplay(
) → void -
Available on UIPageControl, provided by the UIPageControl$Methods extension
update page display to match the currentPage. ignored if defersCurrentPageDisplay is NO. setting the page value directly will update immediately