hidesForSinglePage property
bool
get
hidesForSinglePage
hides the indicator if there is only one page, default is NO
Implementation
bool get hidesForSinglePage {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIPageControl.hidesForSinglePage', iOS: (false, (2, 0, 0)));
return _objc_msgSend_91o635(_$$ref.pointer, _sel_hidesForSinglePage);
}
set
hidesForSinglePage
(bool value)
hides the indicator if there is only one page, default is NO
Implementation
set hidesForSinglePage(bool value) {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIPageControl.setHidesForSinglePage:', iOS: (false, (2, 0, 0)));
_objc_msgSend_1s56lr9(_$$ref.pointer, _sel_setHidesForSinglePage_, value);
}