updateCurrentPageDisplay method

  1. @Deprecated('updateCurrentPageDisplay no longer does anything reasonable with the new interaction mode.')
void updateCurrentPageDisplay()

update page display to match the currentPage. ignored if defersCurrentPageDisplay is NO. setting the page value directly will update immediately

Implementation

@Deprecated('updateCurrentPageDisplay no longer does anything reasonable with the new interaction mode.')
void updateCurrentPageDisplay() {
  final _$$ref = object$.ref;
  objc.checkOsVersionInternal('UIPageControl.updateCurrentPageDisplay', iOS: (false, (2, 0, 0)));
  _objc_msgSend_1pl9qdv(_$$ref.pointer, _sel_updateCurrentPageDisplay);
}