UITextField$Methods extension
- on
Properties
- adjustsFontForContentSizeCategory ↔ bool
-
Available on UITextField, provided by the UITextField$Methods extension
adjustsFontForContentSizeCategorygetter/setter pair - adjustsFontSizeToFitWidth ↔ bool
-
Available on UITextField, provided by the UITextField$Methods extension
adjustsFontSizeToFitWidthgetter/setter pair - allowsEditingTextAttributes ↔ bool
-
Available on UITextField, provided by the UITextField$Methods extension
allowsEditingTextAttributesgetter/setter pair - attributedPlaceholder ↔ NSAttributedString?
-
Available on UITextField, provided by the UITextField$Methods extension
attributedPlaceholdergetter/setter pair - attributedText ↔ NSAttributedString?
-
Available on UITextField, provided by the UITextField$Methods extension
attributedTextgetter/setter pair - autocapitalizationType ↔ UITextAutocapitalizationType
-
Available on UITextField, provided by the UITextField$Methods extension
autocapitalizationTypegetter/setter pair - autocorrectionType ↔ UITextAutocorrectionType
-
Available on UITextField, provided by the UITextField$Methods extension
autocorrectionTypegetter/setter pair - background ↔ UIImage?
-
Available on UITextField, provided by the UITextField$Methods extension
backgroundgetter/setter pair - beginningOfDocument → UITextPosition
-
Available on UITextField, provided by the UITextField$Methods extension
beginningOfDocumentno setter - borderStyle ↔ UITextBorderStyle
-
Available on UITextField, provided by the UITextField$Methods extension
borderStylegetter/setter pair - clearButtonMode ↔ UITextFieldViewMode
-
Available on UITextField, provided by the UITextField$Methods extension
clearButtonModegetter/setter pair - clearsOnBeginEditing ↔ bool
-
Available on UITextField, provided by the UITextField$Methods extension
clearsOnBeginEditinggetter/setter pair - clearsOnInsertion ↔ bool
-
Available on UITextField, provided by the UITextField$Methods extension
clearsOnInsertiongetter/setter pair - defaultTextAttributes ↔ NSDictionary
-
Available on UITextField, provided by the UITextField$Methods extension
defaultTextAttributesgetter/setter pair - delegate ↔ UITextFieldDelegate?
-
Available on UITextField, provided by the UITextField$Methods extension
delegategetter/setter pair - disabledBackground ↔ UIImage?
-
Available on UITextField, provided by the UITextField$Methods extension
disabledBackgroundgetter/setter pair - enablesReturnKeyAutomatically ↔ bool
-
Available on UITextField, provided by the UITextField$Methods extension
enablesReturnKeyAutomaticallygetter/setter pair - endOfDocument → UITextPosition
-
Available on UITextField, provided by the UITextField$Methods extension
endOfDocumentno setter - font ↔ UIFont?
-
Available on UITextField, provided by the UITextField$Methods extension
fontgetter/setter pair - hasText → bool
-
Available on UITextField, provided by the UITextField$Methods extension
hasTextno setter - inputAccessoryView ↔ UIView?
-
Available on UITextField, provided by the UITextField$Methods extension
inputAccessoryViewgetter/setter pair - inputDelegate ↔ UITextInputDelegate?
-
Available on UITextField, provided by the UITextField$Methods extension
inputDelegategetter/setter pair - inputView ↔ UIView?
-
Available on UITextField, provided by the UITextField$Methods extension
inputViewgetter/setter pair - insertDictationResultPlaceholder → ObjCObject
-
Available on UITextField, provided by the UITextField$Methods extension
insertDictationResultPlaceholderno setter - isEditing → bool
-
Available on UITextField, provided by the UITextField$Methods extension
isEditingno setter - isSecureTextEntry ↔ bool
-
Available on UITextField, provided by the UITextField$Methods extension
isSecureTextEntrygetter/setter pair - keyboardAppearance ↔ UIKeyboardAppearance
-
Available on UITextField, provided by the UITextField$Methods extension
keyboardAppearancegetter/setter pair - keyboardType ↔ UIKeyboardType
-
Available on UITextField, provided by the UITextField$Methods extension
keyboardTypegetter/setter pair - leftView ↔ UIView?
-
Available on UITextField, provided by the UITextField$Methods extension
leftViewgetter/setter pair - leftViewMode ↔ UITextFieldViewMode
-
Available on UITextField, provided by the UITextField$Methods extension
leftViewModegetter/setter pair - markedTextRange → UITextRange?
-
Available on UITextField, provided by the UITextField$Methods extension
markedTextRangeno setter - markedTextStyle ↔ NSDictionary?
-
Available on UITextField, provided by the UITextField$Methods extension
markedTextStylegetter/setter pair - minimumFontSize ↔ double
-
Available on UITextField, provided by the UITextField$Methods extension
minimumFontSizegetter/setter pair - passwordRules ↔ UITextInputPasswordRules?
-
Available on UITextField, provided by the UITextField$Methods extension
passwordRulesgetter/setter pair - placeholder ↔ NSString?
-
Available on UITextField, provided by the UITextField$Methods extension
placeholdergetter/setter pair - returnKeyType ↔ UIReturnKeyType
-
Available on UITextField, provided by the UITextField$Methods extension
returnKeyTypegetter/setter pair - rightView ↔ UIView?
-
Available on UITextField, provided by the UITextField$Methods extension
rightViewgetter/setter pair - rightViewMode ↔ UITextFieldViewMode
-
Available on UITextField, provided by the UITextField$Methods extension
rightViewModegetter/setter pair - selectedTextRange ↔ UITextRange?
-
Available on UITextField, provided by the UITextField$Methods extension
selectedTextRangegetter/setter pair - selectionAffinity ↔ UITextStorageDirection
-
Available on UITextField, provided by the UITextField$Methods extension
selectionAffinitygetter/setter pair - smartDashesType ↔ UITextSmartDashesType
-
Available on UITextField, provided by the UITextField$Methods extension
smartDashesTypegetter/setter pair - smartInsertDeleteType ↔ UITextSmartInsertDeleteType
-
Available on UITextField, provided by the UITextField$Methods extension
smartInsertDeleteTypegetter/setter pair - smartQuotesType ↔ UITextSmartQuotesType
-
Available on UITextField, provided by the UITextField$Methods extension
smartQuotesTypegetter/setter pair - spellCheckingType ↔ UITextSpellCheckingType
-
Available on UITextField, provided by the UITextField$Methods extension
spellCheckingTypegetter/setter pair - text ↔ NSString?
-
Available on UITextField, provided by the UITextField$Methods extension
textgetter/setter pair - textAlignment ↔ NSTextAlignment
-
Available on UITextField, provided by the UITextField$Methods extension
textAlignmentgetter/setter pair - textColor ↔ UIColor?
-
Available on UITextField, provided by the UITextField$Methods extension
textColorgetter/setter pair - textContentType ↔ NSString
-
Available on UITextField, provided by the UITextField$Methods extension
textContentTypegetter/setter pair - textInputView → UIView
-
Available on UITextField, provided by the UITextField$Methods extension
textInputViewno setter - tokenizer → UITextInputTokenizer
-
Available on UITextField, provided by the UITextField$Methods extension
tokenizerno setter - typingAttributes ↔ NSDictionary?
-
Available on UITextField, provided by the UITextField$Methods extension
typingAttributesgetter/setter pair
Methods
-
baseWritingDirectionForPosition(
UITextPosition position, {required UITextStorageDirection inDirection}) → NSWritingDirection -
Available on UITextField, provided by the UITextField$Methods extension
baseWritingDirectionForPosition:inDirection: -
beginFloatingCursorAtPoint(
CGPoint point) → void -
Available on UITextField, provided by the UITextField$Methods extension
beginFloatingCursorAtPoint: -
borderRectForBounds(
CGRect bounds) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
borderRectForBounds: -
caretRectForPosition(
UITextPosition position) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
caretRectForPosition: -
characterOffsetOfPosition(
UITextPosition position, {required UITextRange withinRange}) → int -
Available on UITextField, provided by the UITextField$Methods extension
characterOffsetOfPosition:withinRange: -
characterRangeAtPoint(
CGPoint point) → UITextRange? -
Available on UITextField, provided by the UITextField$Methods extension
characterRangeAtPoint: -
characterRangeByExtendingPosition(
UITextPosition position, {required UITextLayoutDirection inDirection}) → UITextRange? -
Available on UITextField, provided by the UITextField$Methods extension
characterRangeByExtendingPosition:inDirection: -
clearButtonRectForBounds(
CGRect bounds) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
clearButtonRectForBounds: -
closestPositionToPoint(
CGPoint point) → UITextPosition? -
Available on UITextField, provided by the UITextField$Methods extension
closestPositionToPoint: -
closestPositionToPoint$1(
CGPoint point, {required UITextRange withinRange}) → UITextPosition? -
Available on UITextField, provided by the UITextField$Methods extension
closestPositionToPoint:withinRange: -
comparePosition(
UITextPosition position, {required UITextPosition toPosition}) → NSComparisonResult -
Available on UITextField, provided by the UITextField$Methods extension
comparePosition:toPosition: -
deleteBackward(
) → void -
Available on UITextField, provided by the UITextField$Methods extension
deleteBackward -
dictationRecognitionFailed(
) → void -
Available on UITextField, provided by the UITextField$Methods extension
dictationRecognitionFailed -
dictationRecordingDidEnd(
) → void -
Available on UITextField, provided by the UITextField$Methods extension
dictationRecordingDidEnd -
drawPlaceholderInRect(
CGRect rect) → void -
Available on UITextField, provided by the UITextField$Methods extension
drawPlaceholderInRect: -
drawTextInRect(
CGRect rect) → void -
Available on UITextField, provided by the UITextField$Methods extension
drawTextInRect: -
editingRectForBounds(
CGRect bounds) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
editingRectForBounds: -
encodeWithCoder(
NSCoder coder) → void -
Available on UITextField, provided by the UITextField$Methods extension
encodeWithCoder: -
endFloatingCursor(
) → void -
Available on UITextField, provided by the UITextField$Methods extension
endFloatingCursor -
firstRectForRange(
UITextRange range) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
firstRectForRange: -
frameForDictationResultPlaceholder(
ObjCObject placeholder) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
frameForDictationResultPlaceholder: -
init(
) → UITextField -
Available on UITextField, provided by the UITextField$Methods extension
init -
initWithCoder(
NSCoder coder) → UITextField? -
Available on UITextField, provided by the UITextField$Methods extension
initWithCoder: -
initWithFrame(
CGRect frame) → UITextField -
Available on UITextField, provided by the UITextField$Methods extension
initWithFrame: -
initWithFrame$1(
CGRect frame, {UIAction? primaryAction}) → UITextField -
Available on UITextField, provided by the UITextField$Methods extension
Initializes the control and adds primaryAction for the UIControlEventPrimaryActionTriggered control event. Subclasses of UIControl may alter or add behaviors around the usage of primaryAction, see subclass documentation of this initializer for additional information. -
insertDictationResult(
NSArray dictationResult) → void -
Available on UITextField, provided by the UITextField$Methods extension
insertDictationResult: -
insertText(
NSString text) → void -
Available on UITextField, provided by the UITextField$Methods extension
insertText: -
insertText$1(
NSString text, {required NSArray alternatives, required UITextAlternativeStyle style}) → void -
Available on UITextField, provided by the UITextField$Methods extension
insertText:alternatives:style: -
insertTextPlaceholderWithSize(
CGSize size) → UITextPlaceholder -
Available on UITextField, provided by the UITextField$Methods extension
insertTextPlaceholderWithSize: -
leftViewRectForBounds(
CGRect bounds) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
leftViewRectForBounds: -
offsetFromPosition(
UITextPosition from, {required UITextPosition toPosition}) → int -
Available on UITextField, provided by the UITextField$Methods extension
offsetFromPosition:toPosition: -
placeholderRectForBounds(
CGRect bounds) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
placeholderRectForBounds: -
positionFromPosition(
UITextPosition position, {required UITextLayoutDirection inDirection, required int offset}) → UITextPosition? -
Available on UITextField, provided by the UITextField$Methods extension
positionFromPosition:inDirection:offset: -
positionFromPosition$1(
UITextPosition position, {required int offset}) → UITextPosition? -
Available on UITextField, provided by the UITextField$Methods extension
positionFromPosition:offset: -
positionWithinRange(
UITextRange range, {required int atCharacterOffset}) → UITextPosition? -
Available on UITextField, provided by the UITextField$Methods extension
positionWithinRange:atCharacterOffset: -
positionWithinRange$1(
UITextRange range, {required UITextLayoutDirection farthestInDirection}) → UITextPosition? -
Available on UITextField, provided by the UITextField$Methods extension
positionWithinRange:farthestInDirection: -
removeDictationResultPlaceholder(
ObjCObject placeholder, {required bool willInsertResult}) → void -
Available on UITextField, provided by the UITextField$Methods extension
removeDictationResultPlaceholder:willInsertResult: -
removeTextPlaceholder(
UITextPlaceholder textPlaceholder) → void -
Available on UITextField, provided by the UITextField$Methods extension
removeTextPlaceholder: -
replaceRange(
UITextRange range, {required NSString withText}) → void -
Available on UITextField, provided by the UITextField$Methods extension
replaceRange:withText: -
rightViewRectForBounds(
CGRect bounds) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
rightViewRectForBounds: -
selectionRectsForRange(
UITextRange range) → NSArray -
Available on UITextField, provided by the UITextField$Methods extension
selectionRectsForRange: -
setAttributedMarkedText(
NSAttributedString? markedText, {required NSRange selectedRange}) → void -
Available on UITextField, provided by the UITextField$Methods extension
setAttributedMarkedText:selectedRange: -
setBaseWritingDirection(
NSWritingDirection writingDirection, {required UITextRange forRange}) → void -
Available on UITextField, provided by the UITextField$Methods extension
setBaseWritingDirection:forRange: -
setMarkedText(
NSString? markedText, {required NSRange selectedRange}) → void -
Available on UITextField, provided by the UITextField$Methods extension
setMarkedText:selectedRange: -
shouldChangeTextInRange(
UITextRange range, {required NSString replacementText}) → bool -
Available on UITextField, provided by the UITextField$Methods extension
shouldChangeTextInRange:replacementText: -
textInRange(
UITextRange range) → NSString? -
Available on UITextField, provided by the UITextField$Methods extension
textInRange: -
textRangeFromPosition(
UITextPosition fromPosition, {required UITextPosition toPosition}) → UITextRange? -
Available on UITextField, provided by the UITextField$Methods extension
textRangeFromPosition:toPosition: -
textRectForBounds(
CGRect bounds) → CGRect -
Available on UITextField, provided by the UITextField$Methods extension
textRectForBounds: -
textStylingAtPosition(
UITextPosition position, {required UITextStorageDirection inDirection}) → NSDictionary? -
Available on UITextField, provided by the UITextField$Methods extension
textStylingAtPosition:inDirection: -
unmarkText(
) → void -
Available on UITextField, provided by the UITextField$Methods extension
unmarkText -
updateFloatingCursorAtPoint(
CGPoint point) → void -
Available on UITextField, provided by the UITextField$Methods extension
updateFloatingCursorAtPoint: