activityItemsConfigurationSource property
UIActivityItemsConfigurationProviding?
get
activityItemsConfigurationSource
An optional object used as a source of scene-level activity items configuration
If this property returns @c nil, the @c activityItemsConfiguration property of the most-presented view controller of the scene's key window will be used for scene-level sharing and activities.
Implementation
UIActivityItemsConfigurationProviding? get activityItemsConfigurationSource {
final _$$ref = object$.ref;
objc.checkOsVersionInternal('UIWindowScene.activityItemsConfigurationSource', iOS: (false, (15, 0, 0)));
final $ret = _objc_msgSend_151sglz(_$$ref.pointer, _sel_activityItemsConfigurationSource);
return $ret.address == 0
? null
: UIActivityItemsConfigurationProviding.fromPointer($ret, retain: true, release: true);
}
set
activityItemsConfigurationSource
(UIActivityItemsConfigurationProviding? value)
An optional object used as a source of scene-level activity items configuration
If this property returns @c nil, the @c activityItemsConfiguration property of the most-presented view controller of the scene's key window will be used for scene-level sharing and activities.
Implementation
set activityItemsConfigurationSource(UIActivityItemsConfigurationProviding? value) {
final _$$ref = object$.ref;
final _$$ref$1 = value?.ref;
objc.checkOsVersionInternal('UIWindowScene.setActivityItemsConfigurationSource:', iOS: (false, (15, 0, 0)));
_objc_msgSend_xtuoz7(_$$ref.pointer, _sel_setActivityItemsConfigurationSource_, _$$ref$1?.pointer ?? ffi.nullptr);
}